@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010 Aurimas Cernius
+ * Copyright (C) 2010,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,8 @@
 namespace gnote {
 
   AbstractAddin::AbstractAddin()
-    : m_disposing(false)
+    : m_gnote(NULL)
+    , m_disposing(false)
   {
   }
 
