@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2011,2013-2014,2016-2017 Aurimas Cernius
+ * Copyright (C) 2010-2011,2013-2014,2016-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,10 +25,10 @@
 #include "sharp/string.hpp"
 #include "backlinksnoteaddin.hpp"
 #include "iactionmanager.hpp"
+#include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "notemanagerbase.hpp"
 #include "preferences.hpp"
-#include "utils.hpp"
 
 namespace backlinks {
 
@@ -65,29 +65,28 @@ void BacklinksNoteAddin::on_open_note(const Glib::VariantBase & param)
   Glib::ustring uri = Glib::VariantBase::cast_dynamic<Glib::Variant<Glib::ustring>>(param).get();
   gnote::NoteBase::Ptr note = get_note()->manager().find_by_uri(uri);
   if(note) {
-    gnote::MainWindow::present_in_new_window(static_pointer_cast<gnote::Note>(note),
-      gnote::Preferences::obj().get_schema_settings(gnote::Preferences::SCHEMA_GNOTE)->
+    gnote::MainWindow::present_in_new_window(ignote(), std::static_pointer_cast<gnote::Note>(note),
+      ignote().preferences().get_schema_settings(gnote::Preferences::SCHEMA_GNOTE)->
         get_boolean(gnote::Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
   }
 }
 
-std::map<int, Gtk::Widget*> BacklinksNoteAddin::get_actions_popover_widgets() const
+std::vector<gnote::PopoverWidget> BacklinksNoteAddin::get_actions_popover_widgets() const
 {
   auto widgets = NoteAddin::get_actions_popover_widgets();
   auto menu_button = gnote::utils::create_popover_submenu_button("backlinks-menu", _("What links here?"));
-  gnote::utils::add_item_to_ordered_map(widgets, gnote::BACKLINKS_ORDER, menu_button);
+  widgets.push_back(gnote::PopoverWidget(gnote::NOTE_SECTION_CUSTOM_SECTIONS, gnote::BACKLINKS_ORDER, menu_button));
 
   auto submenu = gnote::utils::create_popover_submenu("backlinks-menu");
   update_menu(submenu);
-  gnote::utils::add_item_to_ordered_map(widgets, 100000, submenu);
+  widgets.push_back(gnote::PopoverWidget::create_custom_section(submenu));
 
   return widgets;
 }
 
 void BacklinksNoteAddin::update_menu(Gtk::Box *menu) const
 {
-  std::list<Gtk::Widget*> items;
-  get_backlink_menu_items(items);
+  auto items = get_backlink_menu_items();
   bool have_items = false;
   for(auto item : items) {
     dynamic_cast<Gtk::ModelButton*>(item)->property_inverted() = true;
@@ -107,10 +106,11 @@ void BacklinksNoteAddin::update_menu(Gtk::Box *menu) const
 }
 
 
-void BacklinksNoteAddin::get_backlink_menu_items(std::list<Gtk::Widget*> & items) const
+std::vector<Gtk::Widget*> BacklinksNoteAddin::get_backlink_menu_items() const
 {
+  std::vector<Gtk::Widget*> items;
   gnote::NoteBase::List notes = get_note()->manager().get_notes_linking_to(get_note()->get_title());
-  FOREACH(const gnote::NoteBase::Ptr & note, notes) {
+  for(const gnote::NoteBase::Ptr & note : notes) {
     if(note != get_note()) { // don't match ourself
       auto button = manage(gnote::utils::create_popover_button("win.backlinks-open-note", note->get_title()));
       gtk_actionable_set_action_target_value(GTK_ACTIONABLE(button->gobj()),
@@ -119,10 +119,12 @@ void BacklinksNoteAddin::get_backlink_menu_items(std::list<Gtk::Widget*> & items
     }
   }
 
-  items.sort([](Gtk::Widget *x, Gtk::Widget *y)
+  std::sort(items.begin(), items.end(), [](Gtk::Widget *x, Gtk::Widget *y)
     {
       return dynamic_cast<Gtk::ModelButton*>(x)->get_label() < dynamic_cast<Gtk::ModelButton*>(y)->get_label();
     });
+
+  return items;
 }
 
 
