@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2017 Aurimas Cernius
+ * Copyright (C) 2013,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -30,14 +30,17 @@
 #include <gtkmm/treemodelcolumn.h>
 #include <gtkmm/treeview.h>
 
-#include "base/macros.hpp"
-
 namespace sharp {
 
   class FileInfo;
 
 }
 
+namespace gnote {
+  class Preferences;
+}
+
+
 namespace bugzilla {
 
 
@@ -45,7 +48,7 @@ class BugzillaPreferences
   : public Gtk::Grid
 {
 public:
-  BugzillaPreferences(gnote::NoteManager &);
+  BugzillaPreferences(gnote::IGnote &, gnote::Preferences &, gnote::NoteManager &);
 
 protected:
   virtual void on_realize() override;
