@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013,2017 Aurimas Cernius
+ * Copyright (C) 2011-2013,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -27,8 +27,6 @@
 #include "preferences.hpp"
 #include "inserttimestamppreferences.hpp"
  
-using gnote::Preferences;
-
 namespace inserttimestamp {
 
   const char * SCHEMA_INSERT_TIMESTAMP = "org.gnome.gnote.insert-timestamp";
@@ -51,7 +49,8 @@ namespace inserttimestamp {
   }
 
 
-  InsertTimestampPreferences::InsertTimestampPreferences(gnote::NoteManager &)
+  InsertTimestampPreferences::InsertTimestampPreferences(gnote::IGnote &, gnote::Preferences & preferences, gnote::NoteManager &)
+    : m_preferences(preferences)
   {
     _init_static();
 
@@ -59,10 +58,10 @@ namespace inserttimestamp {
     int row = 0;
 
     // Get current values
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(SCHEMA_INSERT_TIMESTAMP);
+    Glib::RefPtr<Gio::Settings> settings = preferences.get_schema_settings(SCHEMA_INSERT_TIMESTAMP);
     Glib::ustring dateFormat = settings->get_string(INSERT_TIMESTAMP_FORMAT);
 
-    sharp::DateTime now = sharp::DateTime::now();
+    auto now = Glib::DateTime::create_now_local();
 
     // Label
     Gtk::Label *label = manage(new Gtk::Label (_("Choose one of the predefined formats "
@@ -82,7 +81,7 @@ namespace inserttimestamp {
 
     for(auto format : s_formats) {
       Gtk::TreeIter treeiter = store->append();
-      treeiter->set_value(0, now.to_string(format));
+      treeiter->set_value(0, sharp::date_time_to_string(now, format));
       treeiter->set_value(1, format);
     }
 
@@ -182,8 +181,7 @@ namespace inserttimestamp {
     if (iter) {
       Glib::ustring format;
       iter->get_value(1, format);
-      Preferences::obj().get_schema_settings(SCHEMA_INSERT_TIMESTAMP)->set_string(
-          INSERT_TIMESTAMP_FORMAT, format);
+      m_preferences.get_schema_settings(SCHEMA_INSERT_TIMESTAMP)->set_string(INSERT_TIMESTAMP_FORMAT, format);
     }
   }
 
