@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2016 Aurimas Cernius
+ * Copyright (C) 2013,2016,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 
 #include "debug.hpp"
 #include "iactionmanager.hpp"
-#include "itagmanager.hpp"
+#include "notemanagerbase.hpp"
 #include "notewindow.hpp"
 #include "readonlynoteaddin.hpp"
 #include "tag.hpp"
@@ -63,18 +63,18 @@ void ReadOnlyNoteAddin::on_note_opened()
   get_window()->signal_backgrounded.connect(sigc::mem_fun(*this, &ReadOnlyNoteAddin::on_background));
 }
 
-std::map<int, Gtk::Widget*> ReadOnlyNoteAddin::get_actions_popover_widgets() const
+std::vector<gnote::PopoverWidget> ReadOnlyNoteAddin::get_actions_popover_widgets() const
 {
   auto widgets = NoteAddin::get_actions_popover_widgets();
   auto button = gnote::utils::create_popover_button("win.readonly-toggle", _("Read Only"));
-  gnote::utils::add_item_to_ordered_map(widgets, gnote::READ_ONLY_ORDER, button);
+  widgets.push_back(gnote::PopoverWidget(gnote::NOTE_SECTION_FLAGS, gnote::READ_ONLY_ORDER, button));
   return widgets;
 }
 
 void ReadOnlyNoteAddin::on_foreground()
 {
   auto action = get_window()->host()->find_action("readonly-toggle");
-  gnote::ITagManager & m = gnote::ITagManager::obj();
+  gnote::ITagManager & m = manager().tag_manager();
   const gnote::Tag::Ptr ro_tag = m.get_or_create_system_tag("read-only");
 
   m_readonly_toggle_cid = action->signal_change_state()
@@ -89,7 +89,7 @@ void ReadOnlyNoteAddin::on_background()
 
 void ReadOnlyNoteAddin::on_menu_item_toggled(const Glib::VariantBase & state)
 {
-  gnote::ITagManager & m = gnote::ITagManager::obj();
+  gnote::ITagManager & m = manager().tag_manager();
   const gnote::Tag::Ptr ro_tag = m.get_or_create_system_tag("read-only");
   bool read_only = Glib::VariantBase::cast_dynamic<Glib::Variant<bool>>(state).get();
   auto action = get_window()->host()->find_action("readonly-toggle");
