@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2013-2014,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <gtkmm/treestore.h>
 
 #include "debug.hpp"
+#include "ignote.hpp"
 #include "itagmanager.hpp"
 #include "statisticswidget.hpp"
 #include "notebooks/notebookmanager.hpp"
@@ -34,9 +35,9 @@ class StatisticsModel
 {
 public:
   typedef Glib::RefPtr<StatisticsModel> Ptr;
-  static Ptr create(gnote::NoteManager & nm)
+  static Ptr create(gnote::IGnote & g, gnote::NoteManager & nm)
     {
-      return Ptr(new StatisticsModel(nm));
+      return Ptr(new StatisticsModel(g, nm));
     }
 
   void update()
@@ -66,17 +67,18 @@ private:
   };
   StatisticsRecord m_columns;
 
-  StatisticsModel(gnote::NoteManager & nm)
-    : m_note_manager(nm)
+  StatisticsModel(gnote::IGnote & g, gnote::NoteManager & nm)
+    : m_gnote(g)
+    , m_note_manager(nm)
     , m_active(false)
     {
       set_column_types(m_columns);
       build_stats();
       nm.signal_note_added.connect(sigc::mem_fun(*this, &StatisticsModel::on_note_list_changed));
       nm.signal_note_deleted.connect(sigc::mem_fun(*this, &StatisticsModel::on_note_list_changed));
-      gnote::notebooks::NotebookManager::obj().signal_note_added_to_notebook()
+      g.notebook_manager().signal_note_added_to_notebook()
         .connect(sigc::mem_fun(*this, &StatisticsModel::on_notebook_note_list_changed));
-      gnote::notebooks::NotebookManager::obj().signal_note_removed_from_notebook()
+      g.notebook_manager().signal_note_removed_from_notebook()
         .connect(sigc::mem_fun(*this, &StatisticsModel::on_notebook_note_list_changed));
     }
 
@@ -90,7 +92,7 @@ private:
       iter->set_value(0, stat);
       iter->set_value(1, TO_STRING(notes.size()));
 
-      Glib::RefPtr<Gtk::TreeModel> notebooks = gnote::notebooks::NotebookManager::obj().get_notebooks();
+      Glib::RefPtr<Gtk::TreeModel> notebooks = m_gnote.notebook_manager().get_notebooks();
       iter = append();
       stat = _("Total Notebooks:");
       iter->set_value(0, stat);
@@ -104,9 +106,9 @@ private:
         notebook_notes[nbook] = 0;
         ++notebook;
       }
-      gnote::Tag::Ptr template_tag = gnote::ITagManager::obj().get_or_create_system_tag(
+      gnote::Tag::Ptr template_tag = m_note_manager.tag_manager().get_or_create_system_tag(
         gnote::ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-      FOREACH(gnote::NoteBase::Ptr note, notes) {
+      for(gnote::NoteBase::Ptr note : notes) {
         for(std::map<gnote::notebooks::Notebook::Ptr, int>::iterator nb = notebook_notes.begin();
             nb != notebook_notes.end(); ++nb) {
           if(note->contains_tag(nb->first->get_tag()) && !note->contains_tag(template_tag)) {
@@ -140,13 +142,14 @@ private:
       update();
     }
 
+  gnote::IGnote & m_gnote;
   gnote::NoteManager & m_note_manager;
   bool m_active;
 };
 
 
-StatisticsWidget::StatisticsWidget(gnote::NoteManager & nm)
-  : Gtk::TreeView(StatisticsModel::create(nm))
+StatisticsWidget::StatisticsWidget(gnote::IGnote & g, gnote::NoteManager & nm)
+  : Gtk::TreeView(StatisticsModel::create(g, nm))
 {
   set_hexpand(true);
   set_vexpand(true);
