@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2017 Aurimas Cernius
+ * Copyright (C) 2013,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 
 #include <gtkmm/treeview.h>
 
-#include "base/macros.hpp"
 #include "mainwindowembeds.hpp"
 #include "notemanager.hpp"
 
@@ -35,7 +34,7 @@ class StatisticsWidget
   , public gnote::EmbeddableWidget
 {
 public:
-  StatisticsWidget(gnote::NoteManager & nm);
+  StatisticsWidget(gnote::IGnote & g, gnote::NoteManager & nm);
   virtual Glib::ustring get_name() const override;
   virtual void foreground() override;
   virtual void background() override;
