@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -32,13 +32,14 @@
 
 namespace gnote {
 
-class NoteManager;
+class IGnote;
+class NoteManagerBase;
 
 class RemoteControl
   : public IRemoteControl
 {
 public:
-  RemoteControl(const Glib::RefPtr<Gio::DBus::Connection> &, gnote::NoteManager&, const char *, const char *,
+  RemoteControl(const Glib::RefPtr<Gio::DBus::Connection> &, IGnote&, NoteManagerBase&, const char *, const char *,
                 const Glib::RefPtr<Gio::DBus::InterfaceInfo> &);
   virtual ~RemoteControl();
 
@@ -54,10 +55,12 @@ public:
   virtual Glib::ustring FindStartHereNote() override;
   virtual std::vector<Glib::ustring> GetAllNotesWithTag(const Glib::ustring& tag_name) override;
   virtual int32_t GetNoteChangeDate(const Glib::ustring& uri) override;
+  virtual int64_t GetNoteChangeDateUnix(const Glib::ustring& uri) override;
   virtual Glib::ustring GetNoteCompleteXml(const Glib::ustring& uri) override;
   virtual Glib::ustring GetNoteContents(const Glib::ustring& uri) override;
   virtual Glib::ustring GetNoteContentsXml(const Glib::ustring& uri) override;
   virtual int32_t GetNoteCreateDate(const Glib::ustring& uri) override;
+  virtual int64_t GetNoteCreateDateUnix(const Glib::ustring& uri) override;
   virtual Glib::ustring GetNoteTitle(const Glib::ustring& uri) override;
   virtual std::vector<Glib::ustring> GetTagsForNote(const Glib::ustring& uri) override;
   virtual bool HideNote(const Glib::ustring& uri) override;
@@ -76,7 +79,8 @@ private:
   void on_note_saved(const NoteBase::Ptr &);
   MainWindow & present_note(const NoteBase::Ptr &);
 
-  NoteManager & m_manager;
+  IGnote & m_gnote;
+  NoteManagerBase & m_manager;
 };
 
 
