@@ -350,6 +350,7 @@ namespace gnote {
     // e.g on forced quit when we call save for every note.
     if (!m_save_needed)
       return;
+    m_save_needed = false;
 
     DBG_OUT("Saving '%s'...", m_data.data().title().c_str());
 
@@ -446,7 +447,6 @@ namespace gnote {
   {
     try {
       save();
-      m_save_needed = false;
     }
     catch(const sharp::Exception &e) 
     {
@@ -561,6 +561,10 @@ namespace gnote {
         }
       }
     }
+    else {
+      signal_renamed(shared_from_this(), old_title);
+      queue_save(CONTENT_CHANGED);
+    }
   }
 
   void Note::process_rename_link_update_end(int response, Gtk::Dialog *dialog,
@@ -665,7 +669,7 @@ namespace gnote {
   Glib::ustring Note::text_content()
   {
     if(!m_buffer) {
-      get_buffer();
+      return NoteBase::text_content();
     }
     return m_buffer->get_slice(m_buffer->begin(), m_buffer->end());
   }
