@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2016 Aurimas Cernius
+ * Copyright (C) 2012-2016,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 #ifndef __NOTE_ADDIN_HPP_
 #define __NOTE_ADDIN_HPP_
 
-#include <list>
 #include <map>
 
 #include <sigc++/connection.h>
@@ -32,16 +31,14 @@
 #include <gtkmm/menuitem.h>
 #include <gtkmm/toolitem.h>
 
-#include "base/macros.hpp"
 #include "sharp/exception.hpp"
 #include "abstractaddin.hpp"
 #include "note.hpp"
 #include "notebuffer.hpp"
+#include "popoverwidgets.hpp"
 
 namespace gnote {
 
-  class NoteManager;
-
 /// <summary>
 /// A NoteAddin extends the functionality of a note and a NoteWindow.
 /// If you wish to extend Tomboy in a more broad sense, perhaps you
@@ -54,7 +51,7 @@ public:
   static const char * IFACE_NAME;
   /// factory method
 //  static NoteAddin *create() { return NULL; }
-  void initialize(const Note::Ptr & note);
+  void initialize(IGnote & ignote, const Note::Ptr & note);
 
   virtual void dispose(bool) override;
 
@@ -74,7 +71,7 @@ public:
   /// </summary>
   virtual void on_note_opened () = 0;
 
-  virtual std::map<int, Gtk::Widget*> get_actions_popover_widgets() const;
+  virtual std::vector<PopoverWidget> get_actions_popover_widgets() const;
   void register_main_window_action_callback(const Glib::ustring & action, sigc::slot<void, const Glib::VariantBase&> callback);
 
   const Note::Ptr & get_note() const
@@ -118,7 +115,7 @@ private:
 
   Note::Ptr                     m_note;
   sigc::connection              m_note_opened_cid;
-  std::list<Gtk::Widget*>       m_text_menu_items;
+  std::vector<Gtk::Widget*>     m_text_menu_items;
   typedef std::map<Gtk::ToolItem*, int> ToolItemMap;
   ToolItemMap                   m_toolbar_items;
   typedef std::pair<Glib::ustring, sigc::slot<void, const Glib::VariantBase&>> ActionCallback;
