@@ -193,6 +193,7 @@ public:
 
   static Glib::ustring url_from_path(const Glib::ustring &);
   static std::vector<Glib::ustring> parse_tags(const xmlNodePtr tagnodes);
+  static Glib::ustring parse_text_content(const Glib::ustring & content);
 
   NoteBase(const Glib::ustring & filepath, NoteManagerBase & manager);
 
@@ -233,6 +234,7 @@ public:
       return data_synchronizer().text();
     }
   virtual void set_xml_content(const Glib::ustring & xml);
+  virtual Glib::ustring text_content();
   void load_foreign_note_xml(const Glib::ustring & foreignNoteXml, ChangeType changeType);
   std::vector<Tag::Ptr> get_tags() const;
   const NoteData & data() const;
