@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2015,2017 Aurimas Cernius
+ * Copyright (C) 2012-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -33,21 +33,24 @@
 #include "notebooks/notebook.hpp"
 #include "note.hpp"
 #include "tag.hpp"
-#include "base/singleton.hpp"
 
 namespace gnote {
-  namespace notebooks {
+
+class IGnote;
+
+
+namespace notebooks {
 
 
 class NotebookManager
-  : public base::Singleton<NotebookManager>
 {
 public:
   typedef sigc::signal<void, const Note &, const Notebook::Ptr &> NotebookEventHandler;
 
-  NotebookManager(NoteManager &);
+  NotebookManager(NoteManagerBase &);
+  void init();
 
-  NoteManager & note_manager() const
+  NoteManagerBase & note_manager() const
     {
       return m_note_manager;
     }
@@ -81,10 +84,9 @@ public:
   Notebook::Ptr get_notebook_from_note(const NoteBase::Ptr &);
   Notebook::Ptr get_notebook_from_tag(const Tag::Ptr &);
   static bool is_notebook_tag(const Tag::Ptr &);
-  static Notebook::Ptr prompt_create_new_notebook(Gtk::Window *);
-  static Notebook::Ptr prompt_create_new_notebook(Gtk::Window *,
-                                                  const Note::List & notesToAdd);
-  static void prompt_delete_notebook(Gtk::Window *, const Notebook::Ptr &);
+  static Notebook::Ptr prompt_create_new_notebook(IGnote &, Gtk::Window *);
+  static Notebook::Ptr prompt_create_new_notebook(IGnote &, Gtk::Window *, const Note::List & notesToAdd);
+  static void prompt_delete_notebook(IGnote &, Gtk::Window *, const Notebook::Ptr &);
   bool move_note_to_notebook (const Note::Ptr &, const Notebook::Ptr &);
 
   NotebookEventHandler & signal_note_added_to_notebook()
@@ -130,10 +132,11 @@ private:
   NotebookEventHandler                 m_note_added_to_notebook;
   NotebookEventHandler                 m_note_removed_from_notebook;
   Notebook::Ptr                        m_active_notes;
-  NoteManager                        & m_note_manager;
+  NoteManagerBase                    & m_note_manager;
 };
 
-  }
+}
+
 }
 
 #endif
