@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010,2012-2013 Aurimas Cernius
+ * Copyright (C) 2010,2012-2013,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 
 
 
-#include <boost/format.hpp>
 #include <glibmm/i18n.h>
 #include <gtkmm/image.h>
 
 #include "sharp/string.hpp"
 #include "iconmanager.hpp"
+#include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
@@ -36,12 +36,13 @@
 namespace gnote {
   namespace notebooks {
 
-    NotebookNewNoteMenuItem::NotebookNewNoteMenuItem(const Notebook::Ptr & notebook)
-      // TRANSLATORS: %1%: boost format placeholder for the notebook name
-      : Gtk::ImageMenuItem(str(boost::format(_("New \"%1%\" Note")) % notebook->get_name()))
+    NotebookNewNoteMenuItem::NotebookNewNoteMenuItem(const Notebook::Ptr & notebook, IGnote & g)
+      // TRANSLATORS: %1: format placeholder for the notebook name
+      : Gtk::ImageMenuItem(Glib::ustring::compose(_("New \"%1\" Note"), notebook->get_name()))
       , m_notebook(notebook)
+      , m_gnote(g)
     {
-      set_image(*manage(new Gtk::Image(IconManager::obj().get_icon(IconManager::NOTE_NEW, 16))));
+      set_image(*manage(new Gtk::Image(g.icon_manager().get_icon(IconManager::NOTE_NEW, 16))));
       signal_activate().connect(sigc::mem_fun(*this, &NotebookNewNoteMenuItem::on_activated));
     }
 
@@ -55,8 +56,8 @@ namespace gnote {
       
       // Look for the template note and create a new note
       Note::Ptr note = m_notebook->create_notebook_note ();
-      MainWindow::present_in_new_window(note,
-        Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
+      MainWindow::present_in_new_window(m_gnote, note,
+        m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
           Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
     }
 
