@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013 Aurimas Cernius
+ * Copyright (C) 2013,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,6 @@
 
 #include <gtkmm/treeview.h>
 
-#include "base/macros.hpp"
-
 namespace gnote {
 
   class NoteManager;
@@ -37,7 +35,7 @@ namespace gnote {
     : public Gtk::TreeView
   {
   public:
-    NotebooksTreeView(NoteManager & manager, const Glib::RefPtr<Gtk::TreeModel> & model);
+    NotebooksTreeView(NoteManagerBase & manager, const Glib::RefPtr<Gtk::TreeModel> & model);
 
   protected:
     virtual void on_drag_data_received( const Glib::RefPtr<Gdk::DragContext> & context,
@@ -48,7 +46,7 @@ namespace gnote {
                                 int x, int y, guint time) override;
     virtual void on_drag_leave(const Glib::RefPtr<Gdk::DragContext> & context, guint time) override;
   private:
-    NoteManager & m_note_manager;
+    NoteManagerBase & m_note_manager;
   };
 
   }
