@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -55,19 +55,19 @@ namespace gnote {
 
   bool NoteBuffer::get_enable_auto_bulleted_lists() const
   {
-    return Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
+    return m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
         Preferences::ENABLE_AUTO_BULLETED_LISTS);
   }
   
 
-  NoteBuffer::NoteBuffer(const NoteTagTable::Ptr & tags, Note & note_)
+  NoteBuffer::NoteBuffer(const NoteTagTable::Ptr & tags, Note & note_, Preferences & preferences)
     : Gtk::TextBuffer(tags)
     , m_undomanager(NULL)
     , m_note(note_)
+    , m_preferences(preferences)
   {
     m_undomanager = new UndoManager(this);
     signal_insert().connect(sigc::mem_fun(*this, &NoteBuffer::text_insert_event));
-    signal_erase().connect(sigc::mem_fun(*this, &NoteBuffer::range_deleted_event));
     signal_mark_set().connect(sigc::mem_fun(*this, &NoteBuffer::mark_set_event));
 
     signal_apply_tag().connect(sigc::mem_fun(*this, &NoteBuffer::on_tag_applied));
@@ -102,12 +102,7 @@ namespace gnote {
       }
     } 
     else {
-      std::list<Glib::RefPtr<Gtk::TextTag> >::iterator iter = std::find(m_active_tags.begin(), 
-                                                                   m_active_tags.end(), tag);
-      if (iter != m_active_tags.end()) {
-        m_active_tags.erase(iter);
-      }
-      else {
+      if(!utils::remove_swap_back(m_active_tags, tag)) {
         m_active_tags.push_back(tag);
       }
     }
@@ -139,11 +134,7 @@ namespace gnote {
       remove_tag(tag, select_start, select_end);
     } 
     else {
-      std::list<Glib::RefPtr<Gtk::TextTag> >::iterator iter = std::find(m_active_tags.begin(), 
-                                                                   m_active_tags.end(), tag);
-      if (iter != m_active_tags.end()) {
-        m_active_tags.erase(iter);
-      }
+      utils::remove_swap_back(m_active_tags, tag);
     }
   }
 
@@ -293,9 +284,8 @@ namespace gnote {
           remove_tag(*tag_iter, insert_start, pos);
         }
 
-        for(std::list<Glib::RefPtr<Gtk::TextTag> >::const_iterator iter = m_active_tags.begin();
-            iter != m_active_tags.end(); ++iter) {
-          apply_tag(*iter, insert_start, pos);
+        for(auto & tag : m_active_tags) {
+          apply_tag(tag, insert_start, pos);
         }
         m_undomanager->thaw_undo();
       }
@@ -309,11 +299,6 @@ namespace gnote {
         }
 
         if(depth_tag) {
-          Pango::Direction direction = Pango::DIRECTION_LTR;
-          if(text.size() > 0) {
-            direction = Pango::Direction(pango_unichar_direction(text[0]));
-          }
-          change_bullet_direction(pos, direction);
           for(int i = 0; i < depth_tag->get_depth(); ++i) {
             signal_change_text_depth(line_start.get_line(), true);
           }
@@ -325,36 +310,6 @@ namespace gnote {
   }
 
 
-  // Change the direction of a bulleted line to match the new
-  // first character after the previous character is deleted.
-  void NoteBuffer::range_deleted_event(const Gtk::TextIter & start,const Gtk::TextIter & end_iter)
-  {
-    //
-    std::array<Gtk::TextIter, 2> iters;
-    iters[0] = start;
-    iters[1] = end_iter;
-
-    FOREACH(Gtk::TextIter iter, iters) {
-      Gtk::TextIter line_start = iter;
-      line_start.set_line_offset(0);
-
-      if (((iter.get_line_offset() == 3) || (iter.get_line_offset() == 2)) &&
-          find_depth_tag(line_start)) {
-
-        Gtk::TextIter first_char = iter;
-        first_char.set_line_offset(2);
-
-        Pango::Direction direction = Pango::DIRECTION_LTR;
-
-        if (first_char.get_char() > 0)
-          direction = Pango::Direction(pango_unichar_direction(first_char.get_char()));
-
-        change_bullet_direction(first_char, direction);
-      }
-    }
-  }
-
-
   bool NoteBuffer::add_new_line(bool soft_break)
   {
     if (!can_make_bulleted_list() || !get_enable_auto_bulleted_lists())
@@ -432,17 +387,10 @@ namespace gnote {
         iter = get_iter_at_mark(insert_mark);
         Gtk::TextIter start = get_iter_at_line(iter.get_line());
 
-        // Set the direction of the bullet to be the same
-        // as the first character on the new line
-        Pango::Direction direction = prev_depth->get_direction();
-        if ((iter.get_char() != '\n') && (iter.get_char() > 0)) {
-          direction = Pango::Direction(pango_unichar_direction(iter.get_char()));
-        }
-
-        insert_bullet(start, prev_depth->get_depth(), direction);
+        insert_bullet(start, prev_depth->get_depth());
         m_undomanager->thaw_undo();
 
-        signal_new_bullet_inserted(offset, prev_depth->get_depth(), direction);
+        signal_new_bullet_inserted(offset, prev_depth->get_depth());
       }
 
       return true;
@@ -459,12 +407,6 @@ namespace gnote {
       }
       // Remove the '*' or '-' character and the space after
       end_iter.forward_chars(2);
-        
-      // Set the direction of the bullet to be the same as
-      // the first character after the '*' or '-'
-      Pango::Direction direction = Pango::DIRECTION_LTR;
-      if (end_iter.get_char() > 0)
-        direction = Pango::Direction(pango_unichar_direction(end_iter.get_char()));
 
       end_iter = erase(start, end_iter);
       start = end_iter;
@@ -482,10 +424,10 @@ namespace gnote {
         iter.set_line_offset(0);
 
         m_undomanager->freeze_undo();
-        insert_bullet (iter, 0, direction);
+        insert_bullet (iter, 0);
         m_undomanager->thaw_undo();
 
-        signal_new_bullet_inserted(offset, 0, direction);
+        signal_new_bullet_inserted(offset, 0);
       }
 
       return true;
@@ -986,37 +928,11 @@ namespace gnote {
   }
 
 
-  // Change the writing direction (ie. RTL or LTR) of a bullet.
-  // This makes the bulleted line use the correct indent
-  void NoteBuffer::change_bullet_direction(Gtk::TextIter iter, Pango::Direction direction)
-  {
-    iter.set_line_offset(0);
-
-    DepthNoteTag::Ptr tag = find_depth_tag (iter);
-    if (tag) {
-      if ((tag->get_direction() != direction) &&
-          (direction != Pango::DIRECTION_NEUTRAL)) {
-        NoteTagTable::Ptr note_table = NoteTagTable::Ptr::cast_dynamic(get_tag_table());
-
-        // Get the depth tag for the given direction
-        Glib::RefPtr<Gtk::TextTag> new_tag = note_table->get_depth_tag (tag->get_depth(), direction);
-
-        Gtk::TextIter next = iter;
-        next.forward_char ();
-
-        // Replace the old depth tag with the new one
-        remove_all_tags (iter, next);
-        apply_tag (new_tag, iter, next);
-      }
-    }
-  }
-
-
-  void NoteBuffer::insert_bullet(Gtk::TextIter & iter, int depth, Pango::Direction direction)
+  void NoteBuffer::insert_bullet(Gtk::TextIter & iter, int depth)
   {
     NoteTagTable::Ptr note_table = NoteTagTable::Ptr::cast_dynamic(get_tag_table());
 
-    DepthNoteTag::Ptr tag = note_table->get_depth_tag (depth, direction);
+    DepthNoteTag::Ptr tag = note_table->get_depth_tag(depth);
 
     Glib::ustring bullet =
       Glib::ustring(1, s_indent_bullets [depth % NUM_INDENT_BULLETS]) + " ";
@@ -1070,13 +986,7 @@ namespace gnote {
       next.forward_sentence_end ();
       next.backward_sentence_start ();
 
-      // Insert the bullet using the same direction
-      // as the text on the line
-      Pango::Direction direction = Pango::DIRECTION_LTR;
-      if ((next.get_char() > 0) && (next.get_line() == start.get_line()))
-        direction = Pango::Direction(pango_unichar_direction(next.get_char()));
-
-      insert_bullet (start, 0, direction);
+      insert_bullet (start, 0);
     } 
     else {
       // Remove the previous indent
@@ -1084,7 +994,7 @@ namespace gnote {
 
       // Insert the indent at the new depth
       int nextDepth = curr_depth->get_depth() + 1;
-      insert_bullet (start, nextDepth, curr_depth->get_direction());
+      insert_bullet(start, nextDepth);
     }
     undoer().thaw_undo ();
 
@@ -1121,7 +1031,7 @@ namespace gnote {
       int nextDepth = curr_depth->get_depth() - 1;
 
       if (nextDepth != -1) {
-        insert_bullet (start, nextDepth, curr_depth->get_direction());
+        insert_bullet(start, nextDepth);
       }
     }
     undoer().thaw_undo ();
@@ -1514,14 +1424,7 @@ namespace gnote {
           } 
           else if (xml.get_name() == "list-item") {
             if (curr_depth >= 0) {
-              if (xml.get_attribute ("dir") == "rtl") {
-                tag_start.tag =
-                  note_table->get_depth_tag (curr_depth, Pango::DIRECTION_RTL);
-              } 
-              else {
-                tag_start.tag =
-                  note_table->get_depth_tag (curr_depth, Pango::DIRECTION_LTR);
-              }
+              tag_start.tag = note_table->get_depth_tag(curr_depth);
               list_stack.push_front (false);
             } 
             else {
@@ -1590,7 +1493,7 @@ namespace gnote {
               // Do not insert bullet if it's already there
               // this happens when using double identation in bullet list
               if(!note_buffer->find_depth_tag(apply_start)) {
-                note_buffer->insert_bullet (apply_start, depth_tag->get_depth(), depth_tag->get_direction());
+                note_buffer->insert_bullet(apply_start, depth_tag->get_depth());
                 buffer->remove_all_tags (apply_start, apply_start);
                 offset += 2;
               }
