@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -79,7 +79,7 @@ namespace gnote {
     virtual NoteBase::Ptr create_note_from_template(const Glib::ustring & title,
                                                     const NoteBase::Ptr & template_note,
                                                     const Glib::ustring & guid) override;
-    virtual NoteBase::Ptr create_new_note(Glib::ustring title, const Glib::ustring & guid) override;
+    virtual NoteBase::Ptr create_note(Glib::ustring title, Glib::ustring body, const Glib::ustring & guid = Glib::ustring()) override;
     virtual NoteBase::Ptr create_new_note(const Glib::ustring & title, const Glib::ustring & xml_content,
                                           const Glib::ustring & guid) override;
     virtual NoteBase::Ptr note_create_new(const Glib::ustring & title, const Glib::ustring & file_name) override;
