@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@
 #include <gtkmm/texttag.h>
 #include <gtkmm/texttagtable.h>
 
-#include "base/macros.hpp"
 #include "contrast.hpp"
 #include "tag.hpp"
 #include "sharp/exception.hpp"
@@ -223,7 +222,7 @@ class DepthNoteTag
 public:
   typedef Glib::RefPtr<DepthNoteTag> Ptr;
 
-  DepthNoteTag(int depth, Pango::Direction direction);
+  DepthNoteTag(int depth);
 
   int get_depth() const
     { 
@@ -236,7 +235,6 @@ public:
   virtual void write(sharp::XmlWriter &, bool) const override;
 private:
   int            m_depth;
-  Pango::Direction m_direction;
 };
 
 
@@ -295,7 +293,7 @@ public:
   /// <returns>ChangeType to save this NoteTag</returns>
   ChangeType get_change_type(const Glib::RefPtr<Gtk::TextTag> &tag);
 
-  DepthNoteTag::Ptr get_depth_tag(int depth, Pango::Direction direction);
+  DepthNoteTag::Ptr get_depth_tag(int depth);
   DynamicNoteTag::Ptr create_dynamic_tag(const Glib::ustring & );
   void register_dynamic_tag(const Glib::ustring & tag_name, const Factory & factory);
   bool is_dynamic_tag_registered(const Glib::ustring &);
@@ -329,7 +327,7 @@ private:
 
   static NoteTagTable::Ptr           s_instance;
   std::map<Glib::ustring, Factory>   m_tag_types;
-  std::list<Glib::RefPtr<Gtk::TextTag> > m_added_tags;
+  std::vector<Glib::RefPtr<Gtk::TextTag> > m_added_tags;
 
   NoteTag::Ptr m_url_tag;
   NoteTag::Ptr m_link_tag;
