@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2018 Aurimas Cernius
+ * Copyright (C) 2011-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -34,6 +34,7 @@
 #include "debug.hpp"
 #include "addinmanager.hpp"
 #include "iconmanager.hpp"
+#include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "note.hpp"
 #include "notewindow.hpp"
@@ -43,7 +44,6 @@
 #include "utils.hpp"
 #include "undo.hpp"
 #include "search.hpp"
-#include "itagmanager.hpp"
 #include "notebooks/notebookmanager.hpp"
 #include "sharp/exception.hpp"
 #include "mainwindowaction.hpp"
@@ -51,14 +51,14 @@
 
 namespace gnote {
 
-  Glib::RefPtr<Gio::Icon> NoteWindow::get_icon_pin_active()
+  Glib::RefPtr<Gio::Icon> NoteWindow::get_icon_pin_active(IconManager & icon_manager)
   {
-    return IconManager::obj().get_icon(IconManager::PIN_ACTIVE, 22);
+    return icon_manager.get_icon(IconManager::PIN_ACTIVE, 22);
   }
 
-  Glib::RefPtr<Gio::Icon> NoteWindow::get_icon_pin_down()
+  Glib::RefPtr<Gio::Icon> NoteWindow::get_icon_pin_down(IconManager & icon_manager)
   {
-    return IconManager::obj().get_icon(IconManager::PIN_DOWN, 22);
+    return icon_manager.get_icon(IconManager::PIN_DOWN, 22);
   }
 
 
@@ -91,8 +91,9 @@ namespace gnote {
 
 
 
-  NoteWindow::NoteWindow(Note & note)
+  NoteWindow::NoteWindow(Note & note, IGnote & g)
     : m_note(note)
+    , m_gnote(g)
     , m_name(note.get_title())
     , m_height(450)
     , m_width(600)
@@ -100,10 +101,11 @@ namespace gnote {
     , m_global_keys(NULL)
     , m_enabled(true)
   {
-    m_template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-    m_template_save_size_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
-    m_template_save_selection_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
-    m_template_save_title_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
+    ITagManager & tag_manager = note.manager().tag_manager();
+    m_template_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    m_template_save_size_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
+    m_template_save_selection_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
+    m_template_save_title_tag = tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
 
     set_hexpand(true);
     set_vexpand(true);
@@ -115,7 +117,7 @@ namespace gnote {
     m_template_widget = make_template_bar();
 
     // The main editor widget
-    m_editor = manage(new NoteEditor(note.get_buffer()));
+    m_editor = manage(new NoteEditor(note.get_buffer(), g.preferences()));
     m_editor->signal_populate_popup().connect(sigc::mem_fun(*this, &NoteWindow::on_populate_popup));
     m_editor->show();
 
@@ -189,7 +191,7 @@ namespace gnote {
     important_action->set_state(Glib::Variant<bool>::create(m_note.is_pinned()));
     m_important_note_slot = important_action->signal_change_state()
       .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_button_clicked));
-    notebooks::NotebookManager::obj().signal_note_pin_status_changed
+    m_gnote.notebook_manager().signal_note_pin_status_changed
       .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_status_changed));
 
   }
@@ -224,8 +226,7 @@ namespace gnote {
 
   void NoteWindow::hint_size(int & width, int & height)
   {
-    if (Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
-          Preferences::AUTOSIZE_NOTE_WINDOW)) {
+    if(m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::AUTOSIZE_NOTE_WINDOW)) {
       width = m_width;
       height = m_height;
     }
@@ -304,46 +305,35 @@ namespace gnote {
     return m_embeddable_toolbar;
   }
 
-  std::vector<Gtk::Widget*> NoteWindow::get_popover_widgets()
+  std::vector<PopoverWidget> NoteWindow::get_popover_widgets()
   {
-    std::vector<Gtk::Widget*> widgets;
-    std::map<int, Gtk::Widget*> widget_map;
+    std::vector<PopoverWidget> popover_widgets;
+    popover_widgets.reserve(20);
 
-    Gtk::Widget *new_note = manage(utils::create_popover_button("app.new-note", _("_New Note")));
-    widgets.push_back(new_note);
-    Gtk::Widget *new_window = manage(utils::create_popover_button("app.new-window", _("New _Window")));
-    widgets.push_back(new_window);
-    widgets.push_back(NULL);
-    Gtk::Widget *undo = manage(utils::create_popover_button("win.undo", _("_Undo")));
-    widgets.push_back(undo);
-    Gtk::Widget *redo = manage(utils::create_popover_button("win.redo", _("_Redo")));
-    widgets.push_back(redo);
-    widgets.push_back(NULL);
-
-    Gtk::Widget *link = manage(utils::create_popover_button("win.link", _("_Link to New Note")));
-    widget_map[2000] = link; // place under "note actions", see iactionmanger.hpp
+    Gtk::Widget *new_note = utils::create_popover_button("app.new-note", _("_New Note"));
+    popover_widgets.push_back(PopoverWidget(NOTE_SECTION_NEW, 1, new_note));
+    Gtk::Widget *new_window = utils::create_popover_button("app.new-window", _("New _Window"));
+    popover_widgets.push_back(PopoverWidget(NOTE_SECTION_NEW, 2, new_window));
+    Gtk::Widget *undo = utils::create_popover_button("win.undo", _("_Undo"));
+    popover_widgets.push_back(PopoverWidget(NOTE_SECTION_UNDO, 1, undo));
+    Gtk::Widget *redo = utils::create_popover_button("win.redo", _("_Redo"));
+    popover_widgets.push_back(PopoverWidget(NOTE_SECTION_UNDO, 2, redo));
+    Gtk::Widget *link = utils::create_popover_button("win.link", _("_Link to New Note"));
+    popover_widgets.push_back(PopoverWidget::create_for_note(LINK_ORDER, link));
+    Gtk::Widget *important = utils::create_popover_button("win.important-note", C_("NoteActions", "_Important"));
+    popover_widgets.push_back(PopoverWidget(NOTE_SECTION_FLAGS, IMPORTANT_ORDER, important));
 
     NoteManager & manager = static_cast<NoteManager&>(m_note.manager());
     Note::Ptr note = std::dynamic_pointer_cast<Note>(m_note.shared_from_this());
-    FOREACH(NoteAddin *addin, manager.get_addin_manager().get_note_addins(note)) {
-      utils::merge_ordered_maps(widget_map, addin->get_actions_popover_widgets());
+    for(NoteAddin *addin : manager.get_addin_manager().get_note_addins(note)) {
+      auto addin_widgets = addin->get_actions_popover_widgets();
+      popover_widgets.insert(popover_widgets.end(), addin_widgets.begin(), addin_widgets.end());
     }
 
-    int last_order = 0;
-    for(std::map<int, Gtk::Widget*>::iterator iter = widget_map.begin();
-        iter != widget_map.end(); ++iter) {
-      // put separator between groups
-      if(iter->first < 10000 && (iter->first / 1000) > last_order && widgets.size() > 0 && widgets.back() != NULL) {
-        widgets.push_back(NULL);
-      }
-      last_order = iter->first / 1000;
-      widgets.push_back(iter->second);
-    }
+    auto delete_button = utils::create_popover_button("win.delete-note", _("_Delete…"));
+    popover_widgets.push_back(PopoverWidget(NOTE_SECTION_ACTIONS, 1000, delete_button));
 
-    widgets.push_back(utils::create_popover_button("win.important-note", _("_Important")));
-    widgets.push_back(utils::create_popover_button("win.delete-note", _("_Delete…")));
-
-    return widgets;
+    return popover_widgets;
   }
 
   std::vector<MainWindowAction::Ptr> NoteWindow::get_widget_actions()
@@ -363,8 +353,8 @@ namespace gnote {
   void NoteWindow::on_delete_button_clicked(const Glib::VariantBase&)
   {
     // Prompt for note deletion
-    std::list<Note::Ptr> single_note_list;
-    single_note_list.push_back(static_pointer_cast<Note>(m_note.shared_from_this()));
+    Note::List single_note_list;
+    single_note_list.push_back(std::static_pointer_cast<Note>(m_note.shared_from_this()));
     noteutils::show_deletion_dialog(single_note_list, dynamic_cast<Gtk::Window*>(host()));
   }
 
@@ -571,7 +561,7 @@ namespace gnote {
       m_note.get_buffer()->apply_tag(m_note.get_tag_table()->get_link_tag(), start, end);
     }
 
-    MainWindow::present_in(*dynamic_cast<MainWindow*>(host()), static_pointer_cast<Note>(match));
+    MainWindow::present_in(*dynamic_cast<MainWindow*>(host()), std::static_pointer_cast<Note>(match));
   }
 
   void NoteWindow::open_help_activate()
@@ -622,7 +612,7 @@ namespace gnote {
     embeddable_toolbar()->set_sensitive(m_enabled);
     if(m_global_keys)
       m_global_keys->enabled(m_enabled);
-    FOREACH(const MainWindowAction::Ptr & action, get_widget_actions()) {
+    for(const MainWindowAction::Ptr & action : get_widget_actions()) {
       // A list includes empty actions to mark separators, non-modifying actions are always enabled
       if(action && !Glib::RefPtr<NonModifyingNoteAction>::cast_dynamic(action)) {
         action->set_enabled(enable);
@@ -641,10 +631,7 @@ namespace gnote {
     if (m_current_matches.empty() || m_current_matches.size() == 0)
       return false;
 
-    std::list<Match>::reverse_iterator iter(m_current_matches.rbegin());
-    for ( ; iter != m_current_matches.rend() ; ++iter) {
-      Match & match(*iter);
-      
+    for (auto & match : m_current_matches) {
       Glib::RefPtr<NoteBuffer> buffer = match.buffer;
       Gtk::TextIter selection_start, selection_end;
       buffer->get_selection_bounds(selection_start, selection_end);
@@ -664,10 +651,7 @@ namespace gnote {
     if (m_current_matches.empty() || m_current_matches.size() == 0)
       return false;
 
-    std::list<Match>::iterator iter(m_current_matches.begin());
-    for ( ; iter != m_current_matches.end() ; ++iter) {
-      Match & match(*iter);
-
+    for (auto & match : m_current_matches) {
       Glib::RefPtr<NoteBuffer> buffer = match.buffer;
       Gtk::TextIter selection_start, selection_end;
       buffer->get_selection_bounds(selection_start, selection_end);
@@ -725,9 +709,7 @@ namespace gnote {
       return;
     }
 
-    for(std::list<Match>::iterator iter = m_current_matches.begin();
-        iter != m_current_matches.end(); ++iter) {
-      Match &match(*iter);
+    for(auto & match : m_current_matches) {
       Glib::RefPtr<NoteBuffer> buffer = match.buffer;
 
       if (match.highlighting != highlight) {
@@ -752,9 +734,7 @@ namespace gnote {
     if (!m_current_matches.empty()) {
       highlight_matches (false /* unhighlight */);
 
-      for(std::list<Match>::const_iterator iter = m_current_matches.begin();
-          iter != m_current_matches.end(); ++iter) {
-        const Match &match(*iter);
+      for(auto & match : m_current_matches) {
         match.buffer->delete_mark(match.start_mark);
         match.buffer->delete_mark(match.end_mark);
       }
@@ -767,7 +747,7 @@ namespace gnote {
 
   void NoteFindHandler::find_matches_in_buffer(const Glib::RefPtr<NoteBuffer> & buffer, 
                                                const std::vector<Glib::ustring> & words,
-                                               std::list<NoteFindHandler::Match> & matches)
+                                               std::vector<NoteFindHandler::Match> & matches)
   {
     matches.clear();
     Glib::ustring note_text = buffer->get_slice (buffer->begin(),
@@ -1087,7 +1067,7 @@ namespace gnote {
     }
 
     MainWindow::present_in(*dynamic_cast<MainWindow*>(m_buffer->note().get_window()->host()),
-                           static_pointer_cast<Note>(match));
+                           std::static_pointer_cast<Note>(match));
   }
 
   //
