@@ -83,7 +83,7 @@ namespace gnote {
   };
 
 
-  PreferencesDialog::PreferencesDialog(NoteManager & note_manager)
+  PreferencesDialog::PreferencesDialog(IGnote & ignote, NoteManager & note_manager)
     : Gtk::Dialog()
     , m_sync_addin_combo(NULL)
     , m_selected_sync_addin(NULL)
@@ -92,6 +92,7 @@ namespace gnote {
     , m_reset_sync_addin_button(NULL)
     , m_save_sync_addin_button(NULL)
     , m_rename_behavior_combo(NULL)
+    , m_gnote(ignote)
     , m_addin_manager(note_manager.get_addin_manager())
     , m_note_manager(note_manager)
   {
@@ -163,7 +164,7 @@ namespace gnote {
       add_action_widget (*button, Gtk::RESPONSE_CLOSE);
       set_default_response(Gtk::RESPONSE_CLOSE);
 
-    Preferences::obj().get_schema_settings(
+    m_gnote.preferences().get_schema_settings(
       Preferences::SCHEMA_GNOTE)->signal_changed().connect(
         sigc::mem_fun(*this, &PreferencesDialog::on_preferences_setting_changed));
   }
@@ -186,14 +187,14 @@ namespace gnote {
         m_addin_manager.erase_note_addin_info(id);
     }
     else {
-      ApplicationAddin * const addin = m_addin_manager.get_application_addin(id);
+      ApplicationAddin *addin = m_addin_manager.get_application_addin(id);
       if(addin) {
-        enable_addin(addin, enable);
+        enable_app_addin(addin, enable);
       }
       else {
-        sync::SyncServiceAddin * const sync_addin = m_addin_manager.get_sync_service_addin(id);
+        sync::SyncServiceAddin *sync_addin = m_addin_manager.get_sync_service_addin(id);
         if(sync_addin) {
-          enable_addin(sync_addin, enable);
+          enable_sync_addin(sync_addin, enable);
         }
         else {
           ERR_OUT(_("Plugin %s is absent"), id.c_str());
@@ -206,11 +207,21 @@ namespace gnote {
     m_addin_manager.save_addins_prefs();
   }
 
-  template <typename T>
-  void PreferencesDialog::enable_addin(T *addin, bool enable)
+  void PreferencesDialog::enable_app_addin(ApplicationAddin *addin, bool enable)
   {
     if(enable) {
-      addin->initialize();
+      addin->initialize(m_gnote, m_note_manager);
+    }
+    else {
+      addin->shutdown();
+    }
+  }
+
+
+  void PreferencesDialog::enable_sync_addin(sync::SyncServiceAddin *addin, bool enable)
+  {
+    if(enable) {
+      addin->initialize(m_gnote, m_gnote.sync_manager());
     }
     else {
       addin->shutdown();
@@ -225,7 +236,7 @@ namespace gnote {
       Gtk::Label *label;
       Gtk::CheckButton *check;
       sharp::PropertyEditorBool *peditor, *font_peditor,* bullet_peditor;
-      Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+      Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
 
       Gtk::Grid *options_list = manage(new Gtk::Grid);
       options_list->set_row_spacing(12);
@@ -243,7 +254,7 @@ namespace gnote {
 
       // Spell checking...
 
-#if FIXED_GTKSPELL
+#if ENABLE_GSPELL
       // TODO I'm not sure there is a proper reason to do that.
       // it is in or NOT. if not, disable the UI.
       if (NoteSpellChecker::gtk_spell_available()) {
@@ -354,7 +365,7 @@ namespace gnote {
     button->add (*font_box);
     button->show ();
 
-    Glib::ustring font_desc = Preferences::obj().get_schema_settings(
+    Glib::ustring font_desc = m_gnote.preferences().get_schema_settings(
         Preferences::SCHEMA_GNOTE)->get_string(Preferences::CUSTOM_FONT_FACE);
     update_font_button (font_desc);
 
@@ -371,7 +382,7 @@ namespace gnote {
     Gtk::CheckButton *check;
     sharp::PropertyEditorBool *peditor;
     int vbox_row = 0;
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+    Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
       .get_schema_settings(Preferences::SCHEMA_GNOTE);
 
     // internal links
@@ -448,7 +459,7 @@ namespace gnote {
 
     // Read from Preferences which service is configured and select it
     // by default.  Otherwise, just select the first one in the list.
-    Glib::ustring addin_id = Preferences::obj()
+    Glib::ustring addin_id = m_gnote.preferences()
       .get_schema_settings(Preferences::SCHEMA_SYNC)->get_string(Preferences::SYNC_SELECTED_SERVICE_ADDIN);
 
     Gtk::TreeIter active_iter;
@@ -496,11 +507,11 @@ namespace gnote {
     vbox->attach(*m_sync_addin_prefs_container, 0, vbox_row++, 1, 1);
 
     // Autosync preference
-    int timeout = Preferences::obj().get_schema_settings(
+    int timeout = m_gnote.preferences().get_schema_settings(
         Preferences::SCHEMA_SYNC)->get_int(Preferences::SYNC_AUTOSYNC_TIMEOUT);
     if(timeout > 0 && timeout < 5) {
       timeout = 5;
-      Preferences::obj().get_schema_settings(
+      m_gnote.preferences().get_schema_settings(
           Preferences::SCHEMA_SYNC)->set_int(Preferences::SYNC_AUTOSYNC_TIMEOUT, 5);
     }
     Gtk::Grid *autosyncBox = manage(new Gtk::Grid);
@@ -589,7 +600,7 @@ namespace gnote {
 
     // TreeView of Add-ins
     m_addin_tree = manage(new Gtk::TreeView ());
-    m_addin_tree_model = sharp::AddinsTreeModel::create(m_addin_tree);
+    m_addin_tree_model = sharp::AddinsTreeModel::create(m_gnote.icon_manager(), m_addin_tree);
 
     m_addin_tree->show ();
 
@@ -928,7 +939,7 @@ namespace gnote {
     Gtk::FontSelectionDialog *font_dialog =
       new Gtk::FontSelectionDialog (_("Choose Note Font"));
 
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+    Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
     Glib::ustring font_name = settings->get_string(Preferences::CUSTOM_FONT_FACE);
     font_dialog->set_font_name(font_name);
 
@@ -967,7 +978,7 @@ namespace gnote {
     NoteBase::Ptr template_note = m_note_manager.get_or_create_template_note();
 
     // Open the template note
-    IGnote::obj().open_note(std::static_pointer_cast<Note>(template_note));
+    m_gnote.open_note(std::static_pointer_cast<Note>(template_note));
   }
 
 
@@ -975,7 +986,7 @@ namespace gnote {
   void  PreferencesDialog::on_preferences_setting_changed(const Glib::ustring & key)
   {
     if (key == Preferences::NOTE_RENAME_BEHAVIOR) {
-      Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
         .get_schema_settings(Preferences::SCHEMA_GNOTE);
       int rename_behavior = settings->get_int(key);
       if (0 > rename_behavior || 2 < rename_behavior) {
@@ -988,7 +999,7 @@ namespace gnote {
       }
     }
     else if(key == Preferences::SYNC_AUTOSYNC_TIMEOUT) {
-      int timeout = Preferences::obj().get_schema_settings(
+      int timeout = m_gnote.preferences().get_schema_settings(
           Preferences::SCHEMA_SYNC)->get_int(Preferences::SYNC_AUTOSYNC_TIMEOUT);
       if(timeout <= 0 && m_autosync_check->get_active()) {
         m_autosync_check->set_active(false);
@@ -1009,7 +1020,7 @@ namespace gnote {
 
   void  PreferencesDialog::on_rename_behavior_changed()
   {
-    Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_int(
+    m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_int(
         Preferences::NOTE_RENAME_BEHAVIOR, m_rename_behavior_combo->get_active_row_number());
   }
 
@@ -1018,7 +1029,7 @@ namespace gnote {
   {
     // Get saved behavior
     sync::SyncTitleConflictResolution savedBehavior = sync::CANCEL;
-    int dlgBehaviorPref = Preferences::obj().get_schema_settings(
+    int dlgBehaviorPref = m_gnote.preferences().get_schema_settings(
       Preferences::SCHEMA_SYNC)->get_int(Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR);
     // TODO: Check range of this int
     savedBehavior = static_cast<sync::SyncTitleConflictResolution>(dlgBehaviorPref);
@@ -1085,7 +1096,7 @@ namespace gnote {
       newBehavior = sync::OVERWRITE_EXISTING;
     }
 
-    Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
+    m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
       Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR, static_cast<int>(newBehavior));
   }
 
@@ -1167,13 +1178,13 @@ namespace gnote {
       DBG_OUT("Error calling %s.reset_configuration: %s", m_selected_sync_addin->id().c_str(), e.what());
     }
 
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC);
+    Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC);
     settings->set_string(Preferences::SYNC_SELECTED_SERVICE_ADDIN, "");
 
     // Reset conflict handling behavior
     settings->set_int(Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR, DEFAULT_SYNC_CONFIGURED_CONFLICT_BEHAVIOR);
 
-    sync::ISyncManager::obj().reset_client();
+    m_gnote.sync_manager().reset_client();
 
     m_sync_addin_combo->set_sensitive(true);
     m_sync_addin_combo->unset_active();
@@ -1192,7 +1203,8 @@ namespace gnote {
     try {
       get_window()->set_cursor(Gdk::Cursor::create(Gdk::WATCH));
       get_window()->get_display()->flush();
-      saved = m_selected_sync_addin->save_configuration();
+      set_sensitive(false);
+      saved = m_selected_sync_addin->save_configuration(sigc::mem_fun(*this, &PreferencesDialog::on_sync_settings_saved));
     }
     catch(sync::GnoteSyncException & e) {
       errorMsg = e.what();
@@ -1200,12 +1212,22 @@ namespace gnote {
     catch(std::exception & e) {
       DBG_OUT("Unexpected error calling %s.save_configuration: %s", m_selected_sync_addin->id().c_str(), e.what());
     }
+
+    if(!saved) {
+      on_sync_settings_saved(saved, errorMsg);
+    }
+  }
+
+
+  void PreferencesDialog::on_sync_settings_saved(bool saved, Glib::ustring errorMsg)
+  {
+    set_sensitive(true);
     get_window()->set_cursor(Glib::RefPtr<Gdk::Cursor>());
     get_window()->get_display()->flush();
 
     utils::HIGMessageDialog *dialog;
     if(saved) {
-      Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->set_string(
+      m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->set_string(
         Preferences::SYNC_SELECTED_SERVICE_ADDIN, m_selected_sync_addin->id());
 
       m_sync_addin_combo->set_sensitive(false);
@@ -1213,7 +1235,7 @@ namespace gnote {
       m_reset_sync_addin_button->set_sensitive(true);
       m_save_sync_addin_button->set_sensitive(false);
 
-      sync::ISyncManager::obj().reset_client();
+      m_gnote.sync_manager().reset_client();
 
       // Give the user a visual letting them know that connecting
       // was successful.
@@ -1226,14 +1248,14 @@ namespace gnote {
 
       if(dialog_response == Gtk::RESPONSE_YES) {
         // TODO: Put this voodoo in a method somewhere
-        IActionManager::obj().get_app_action("sync-notes")->activate(Glib::VariantBase());
+        m_gnote.action_manager().get_app_action("sync-notes")->activate(Glib::VariantBase());
       }
     }
     else {
       // TODO: Change the SyncServiceAddin API so the call to
       // SaveConfiguration has a way of passing back an exception
       // or other text so it can be displayed to the user.
-      Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->set_string(
+      m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->set_string(
        Preferences::SYNC_SELECTED_SERVICE_ADDIN, "");
 
       m_sync_addin_combo->set_sensitive(true);
@@ -1407,7 +1429,7 @@ namespace gnote {
 
   void PreferencesDialog::update_timeout_pref()
   {
-    Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
+    m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
         Preferences::SYNC_AUTOSYNC_TIMEOUT,
         m_autosync_check->get_active() ? static_cast<int>(m_autosync_spinner->get_value()) : -1);
   }
