@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013,2015-2017 Aurimas Cernius
+ * Copyright (C) 2011-2013,2015-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -38,14 +38,15 @@
 
 namespace gnote {
 
-class SyncServiceAddin;
+namespace sync { class SyncServiceAddin; }
 class AddinManager;
+class IGnote;
 
 class PreferencesDialog
   : public Gtk::Dialog
 {
 public:
-  explicit PreferencesDialog(NoteManager & note_manager);
+  PreferencesDialog(IGnote & ignote, NoteManager & note_manager);
   
 
   Gtk::Widget *make_editing_pane();
@@ -60,8 +61,8 @@ private:
   Gtk::CheckButton *make_check_button(const Glib::ustring & label_text);
 
   void enable_addin(bool enable);
-  template <typename T>
-  void enable_addin(T *addin, bool enable);
+  void enable_app_addin(ApplicationAddin *addin, bool enable);
+  void enable_sync_addin(sync::SyncServiceAddin *addin, bool enable);
 
   void open_template_button_clicked();
   void on_font_button_clicked();
@@ -70,6 +71,7 @@ private:
   void on_advanced_sync_config_button();
   void on_reset_sync_addin_button(bool signal);
   void on_save_sync_addin_button();
+  void on_sync_settings_saved(bool saved, Glib::ustring errorMsg);
 
   void on_preferences_setting_changed(const Glib::ustring & key);
   void on_rename_behavior_changed();
@@ -119,6 +121,7 @@ private:
   Gtk::CheckButton *m_autosync_check;
   Gtk::SpinButton *m_autosync_spinner;
   Gtk::ComboBoxText *m_rename_behavior_combo;
+  IGnote & m_gnote;
   AddinManager &m_addin_manager;
   NoteManager & m_note_manager;
     
