@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2018 Aurimas Cernius
+ * Copyright (C) 2010-2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -48,10 +48,12 @@ namespace gnote {
     const char *MAIN_MENU_SECONDARY_ICON = "view-more-symbolic";
   }
 
-  NoteRecentChanges::NoteRecentChanges(NoteManager& m)
+  NoteRecentChanges::NoteRecentChanges(IGnote & g, NoteManagerBase & m)
     : MainWindow(_("Gnote"))
+    , m_gnote(g)
     , m_note_manager(m)
-    , m_search_notes_widget(m)
+    , m_preferences(g.preferences())
+    , m_search_notes_widget(g, m)
     , m_search_box(0.5, 0.5, 0.0, 1.0)
     , m_mapped(false)
     , m_entry_changed_timeout(NULL)
@@ -59,7 +61,7 @@ namespace gnote {
     , m_window_menu_default(NULL)
     , m_keybinder(get_accel_group())
   {
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+    Glib::RefPtr<Gio::Settings> settings = g.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
     m_open_notes_in_new_window = settings->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
     m_close_note_on_escape = settings->get_boolean(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE);
     set_default_size(450,400);
@@ -83,7 +85,7 @@ namespace gnote {
     make_search_box();
     m_content_vbox.set_orientation(Gtk::ORIENTATION_VERTICAL);
     int content_y_attach = 0;
-    if(use_client_side_decorations()) {
+    if(use_client_side_decorations(m_preferences)) {
       set_titlebar(*static_cast<Gtk::HeaderBar*>(m_header_bar));
     }
     else {
@@ -100,14 +102,14 @@ namespace gnote {
     signal_delete_event().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_delete));
     signal_key_press_event()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_key_pressed));
-    IGnote::obj().signal_quit
+    g.signal_quit
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));// to save size/pos
     m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
                                 GDK_KEY_W, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
     m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
                                 GDK_KEY_Q, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
 
-    std::map<Glib::ustring, const Glib::VariantType*> actions = IActionManager::obj().get_main_window_actions();
+    std::map<Glib::ustring, const Glib::VariantType*> actions = g.action_manager().get_main_window_actions();
     for(std::map<Glib::ustring, const Glib::VariantType*>::iterator iter = actions.begin();
         iter != actions.end(); ++iter) {
       MainWindowAction::Ptr action;
@@ -124,7 +126,7 @@ namespace gnote {
         add_action(action = MainWindowAction::create(iter->first, Glib::ustring("")));
       }
       if(action) {
-        action->is_modifying(IActionManager::obj().is_modifying_main_window_action(iter->first));
+        action->is_modifying(g.action_manager().is_modifying_main_window_action(iter->first));
       }
     }
     find_action("close-window")->signal_activate()
@@ -204,7 +206,7 @@ namespace gnote {
     right_box->attach(*m_window_actions_button, 1, 0, 1, 1);
     right_box->show();
 
-    if(use_client_side_decorations()) {
+    if(use_client_side_decorations(m_preferences)) {
       Gtk::HeaderBar *header_bar = manage(new Gtk::HeaderBar);
       header_bar->set_show_close_button(true);
       header_bar->pack_start(*left_box);
@@ -347,7 +349,7 @@ namespace gnote {
       search_wgt->new_note();
     }
     else {
-      present_note(static_pointer_cast<Note>(m_note_manager.create()));
+      present_note(std::static_pointer_cast<Note>(m_note_manager.create()));
     }
   }
 
@@ -366,7 +368,7 @@ namespace gnote {
 
   void NoteRecentChanges::on_open_note_new_window(const Note::Ptr & note)
   {
-    present_in_new_window(note, m_close_note_on_escape);
+    present_in_new_window(m_gnote, note, m_close_note_on_escape);
   }
 
   void NoteRecentChanges::on_delete_note()
@@ -381,7 +383,7 @@ namespace gnote {
     Glib::RefPtr<Gdk::Window> win = get_window();
     // background window (for tray to work) might not have GDK window
     if(win) {
-      Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_boolean(
+      m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->set_boolean(
           Preferences::MAIN_WINDOW_MAXIMIZED,
           win->get_state() & Gdk::WINDOW_STATE_MAXIMIZED);
     }
@@ -495,8 +497,7 @@ namespace gnote {
   void NoteRecentChanges::unembed_widget(EmbeddableWidget & widget)
   {
     bool show_other = false;
-    std::list<EmbeddableWidget*>::iterator iter = std::find(
-      m_embedded_widgets.begin(), m_embedded_widgets.end(), &widget);
+    auto iter = std::find(m_embedded_widgets.begin(), m_embedded_widgets.end(), &widget);
     if(iter != m_embedded_widgets.end()) {
       if(is_foreground(**iter)) {
         background_embedded(widget);
@@ -526,7 +527,7 @@ namespace gnote {
       wid.show();
       widget.foreground();
 
-      bool maximized = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
+      bool maximized = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
         Preferences::MAIN_WINDOW_MAXIMIZED);
       if(get_realized()) {
         //if window is showing, use actual state
@@ -591,7 +592,7 @@ namespace gnote {
 
   bool NoteRecentChanges::contains(EmbeddableWidget & widget)
   {
-    FOREACH(EmbeddableWidget *wgt, m_embedded_widgets) {
+    for(EmbeddableWidget *wgt : m_embedded_widgets) {
       if(dynamic_cast<EmbeddableWidget*>(wgt) == &widget) {
         return true;
       }
@@ -602,7 +603,7 @@ namespace gnote {
 
   bool NoteRecentChanges::is_foreground(EmbeddableWidget & widget)
   {
-    FOREACH(Gtk::Widget *wgt, m_embed_box.get_children()) {
+    for(Gtk::Widget *wgt : m_embed_box.get_children()) {
       if(dynamic_cast<EmbeddableWidget*>(wgt) == &widget) {
         return true;
       }
@@ -759,49 +760,52 @@ namespace gnote {
     HasActions *embed_with_actions = dynamic_cast<HasActions*>(currently_embedded());
     if(embed_with_actions) {
       if(m_window_menu_embedded == NULL) {
-        m_window_menu_embedded = make_window_menu(m_window_actions_button, embed_with_actions->get_popover_widgets());
+        m_window_menu_embedded = make_window_menu(m_window_actions_button, std::move(embed_with_actions->get_popover_widgets()));
       }
       m_window_menu_embedded->show_all();
     }
     else {
       if(m_window_menu_default == NULL) {
-        m_window_menu_default = make_window_menu(m_window_actions_button, std::vector<Gtk::Widget*>());
+        m_window_menu_default = make_window_menu(m_window_actions_button, std::vector<PopoverWidget>());
       }
       m_window_menu_default->show_all();
     }
   }
 
-  Gtk::PopoverMenu *NoteRecentChanges::make_window_menu(Gtk::Button *button, const std::vector<Gtk::Widget*> & items)
+  Gtk::PopoverMenu *NoteRecentChanges::make_window_menu(Gtk::Button *button, std::vector<PopoverWidget> && items)
   {
-    std::map<Glib::ustring, Gtk::Widget*> submenus;
+    std::sort(items.begin(), items.end());
     Gtk::PopoverMenu *menu = manage(new Gtk::PopoverMenu);
     Gtk::Box *menu_box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
     utils::set_common_popover_widget_props(*menu_box);
     if(items.size() > 0) {
-      FOREACH(Gtk::Widget *item, items) {
-        if(item) {
-          utils::PopoverSubmenu *submenu = dynamic_cast<utils::PopoverSubmenu*>(item);
+      auto iter = items.begin();
+      auto current_section = iter->section;
+      for(; iter != items.end() && iter->section != APP_CUSTOM_SECTION; ++iter) {
+          if(iter->section != current_section) {
+            current_section = iter->section;
+            menu_box->add(*manage(new Gtk::Separator));
+          }
+          menu_box->add(*manage(iter->widget));
+      }
+
+      menu->add(*menu_box);
+      for(; iter != items.end(); ++iter) {
+          PopoverSubmenu *submenu = dynamic_cast<PopoverSubmenu*>(iter->widget);
           if(submenu) {
-            submenus[submenu->name()] = item;
+            menu->add(*manage(iter->widget));
+            menu->child_property_submenu(*iter->widget) = submenu->name();
           }
           else {
-            menu_box->add(*manage(item));
+            ERR_OUT(_("Expected widget to be a sub-menu!"));
           }
-        }
-        else {
-          menu_box->add(*manage(new Gtk::Separator));
-        }
       }
     }
     else {
       menu_box->add(*manage(new Gtk::Label(_("No configured actions"))));
+      menu->add(*menu_box);
     }
 
-    menu->add(*menu_box);
-    for(auto & submenu : submenus) {
-      menu->add(*submenu.second);
-      menu->child_property_submenu(*submenu.second) = submenu.first;
-    }
     menu->set_relative_to(*button);
     menu->set_modal(true);
     menu->set_position(Gtk::POS_BOTTOM);
@@ -823,11 +827,11 @@ namespace gnote {
   void NoteRecentChanges::on_settings_changed(const Glib::ustring & key)
   {
     if(key == Preferences::OPEN_NOTES_IN_NEW_WINDOW) {
-      m_open_notes_in_new_window = Preferences::obj().get_schema_settings(
+      m_open_notes_in_new_window = m_preferences.get_schema_settings(
         Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
     }
     else if(key == Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE) {
-      m_close_note_on_escape = Preferences::obj().get_schema_settings(
+      m_close_note_on_escape = m_preferences.get_schema_settings(
         Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE);
     }
   }
