@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -29,20 +29,20 @@
 #include <gtkmm/grid.h>
 #include <gtkmm/popovermenu.h>
 
-#include "base/macros.hpp"
 #include "mainwindowaction.hpp"
 #include "note.hpp"
 #include "searchnoteswidget.hpp"
 #include "utils.hpp"
 
 namespace gnote {
-  class NoteManager;
+  class IGnote;
+  class NoteManagerBase;
 
 class NoteRecentChanges
   : public MainWindow
 {
 public:
-  NoteRecentChanges(NoteManager& m);
+  NoteRecentChanges(IGnote & g, NoteManagerBase & m);
   virtual ~NoteRecentChanges();
   virtual void show_search_bar(bool grab_focus = true) override;
   virtual void set_search_text(const Glib::ustring & value) override;
@@ -87,7 +87,7 @@ private:
   void on_search_button_toggled();
   void on_find_next_button_clicked();
   void on_find_prev_button_clicked();
-  Gtk::PopoverMenu *make_window_menu(Gtk::Button *button, const std::vector<Gtk::Widget*> & items);
+  Gtk::PopoverMenu *make_window_menu(Gtk::Button *button, std::vector<PopoverWidget> && items);
   void on_embedded_name_changed(const Glib::ustring & name);
   void on_settings_changed(const Glib::ustring & key);
   bool on_notes_widget_key_press(GdkEventKey*);
@@ -95,7 +95,9 @@ private:
   void add_action(const MainWindowAction::Ptr & action);
   void on_popover_widgets_changed();
 
-  NoteManager        &m_note_manager;
+  IGnote             &m_gnote;
+  NoteManagerBase    &m_note_manager;
+  Preferences        &m_preferences;
   Gtk::Widget        *m_header_bar;
   SearchNotesWidget   m_search_notes_widget;
   Gtk::Grid           m_content_vbox;
@@ -108,7 +110,7 @@ private:
   Gtk::Button        *m_new_note_button;
   Gtk::Button        *m_window_actions_button;
   Gtk::SearchEntry    m_search_entry;
-  std::list<EmbeddableWidget*> m_embedded_widgets;
+  std::vector<EmbeddableWidget*> m_embedded_widgets;
   bool                m_mapped;
   sigc::connection    m_current_embedded_name_slot;
   sigc::connection    m_signal_popover_widgets_changed_cid;
