@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -59,59 +59,58 @@ const char *RemoteControlProxy::GNOTE_SERVER_PATH = "/org/gnome/Gnote/RemoteCont
 const char *RemoteControlProxy::GNOTE_SEARCH_PROVIDER_PATH = "/org/gnome/Gnote/SearchProvider";
 const char *RemoteControlProxy::GNOTE_SEARCH_PROVIDER_INTERFACE_NAME = "org.gnome.Shell.SearchProvider2";
 
-NoteManager *RemoteControlProxy::s_manager;
-RemoteControl *RemoteControlProxy::s_remote_control;
-org::gnome::Gnote::SearchProvider *RemoteControlProxy::s_search_provider;
-bool RemoteControlProxy::s_bus_acquired;
-Glib::RefPtr<Gio::DBus::Connection> RemoteControlProxy::s_connection;
-Glib::RefPtr<RemoteControlClient> RemoteControlProxy::s_remote_control_proxy;
-Glib::RefPtr<Gio::DBus::InterfaceInfo> RemoteControlProxy::s_gnote_interface;
-Glib::RefPtr<Gio::DBus::InterfaceInfo> RemoteControlProxy::s_search_provider_interface;
-RemoteControlProxy::slot_name_acquire_finish RemoteControlProxy::s_on_name_acquire_finish;
 
+RemoteControlProxy::RemoteControlProxy(IGnote & g)
+  : m_gnote(g)
+  , m_manager(NULL)
+  , m_remote_control(NULL)
+  , m_search_provider(NULL)
+  , m_bus_acquired(false)
+{
+}
 
 Glib::RefPtr<RemoteControlClient> RemoteControlProxy::get_instance()
 {
-  if(s_remote_control_proxy) {
-    return s_remote_control_proxy;
+  if(m_remote_control_proxy) {
+    return m_remote_control_proxy;
   }
-  if(!s_connection) {
+  if(!m_connection) {
     return Glib::RefPtr<RemoteControlClient>();
   }
 
   load_introspection_xml();
-  return s_remote_control_proxy = Glib::RefPtr<RemoteControlClient>(
-    new RemoteControlClient(s_connection, GNOTE_SERVER_PATH, GNOTE_SERVER_NAME, GNOTE_INTERFACE_NAME, s_gnote_interface));
+  return m_remote_control_proxy = Glib::RefPtr<RemoteControlClient>(
+    new RemoteControlClient(m_connection, GNOTE_SERVER_PATH, GNOTE_SERVER_NAME, GNOTE_INTERFACE_NAME, m_gnote_interface));
 }
 
 RemoteControl *RemoteControlProxy::get_remote_control()
 {
-  return s_remote_control;
+  return m_remote_control;
 }
 
-void RemoteControlProxy::register_remote(NoteManager & manager, const slot_name_acquire_finish & on_finish)
+void RemoteControlProxy::register_remote(NoteManagerBase & manager, const slot_name_acquire_finish & on_finish)
 {
-  s_on_name_acquire_finish = on_finish;
-  s_manager = &manager;
+  m_on_name_acquire_finish = on_finish;
+  m_manager = &manager;
   Gio::DBus::own_name(Gio::DBus::BUS_TYPE_SESSION, GNOTE_SERVER_NAME,
-                      sigc::ptr_fun(RemoteControlProxy::on_bus_acquired),
-                      sigc::ptr_fun(RemoteControlProxy::on_name_acquired),
-                      sigc::ptr_fun(RemoteControlProxy::on_name_lost));
+                      sigc::mem_fun(*this, &RemoteControlProxy::on_bus_acquired),
+                      sigc::mem_fun(*this, &RemoteControlProxy::on_name_acquired),
+                      sigc::mem_fun(*this, &RemoteControlProxy::on_name_lost));
 }
 
 
 void RemoteControlProxy::on_bus_acquired(const Glib::RefPtr<Gio::DBus::Connection> & conn, const Glib::ustring &)
 {
-  s_bus_acquired = true;
-  s_connection = conn;
+  m_bus_acquired = true;
+  m_connection = conn;
 }
 
 
 void RemoteControlProxy::on_name_acquired(const Glib::RefPtr<Gio::DBus::Connection> & conn, const Glib::ustring &)
 {
   try {
-    if(s_bus_acquired) {
-      register_object(conn, *s_manager, s_on_name_acquire_finish);
+    if(m_bus_acquired) {
+      register_object(conn, *m_manager, m_on_name_acquire_finish);
       return;
     }
   }
@@ -119,32 +118,32 @@ void RemoteControlProxy::on_name_acquired(const Glib::RefPtr<Gio::DBus::Connecti
     DBG_OUT("Failed to acquire name: %s", e.what().c_str());
   }
 
-  s_on_name_acquire_finish(false, false);
+  m_on_name_acquire_finish(false, false);
 }
 
 
-void RemoteControlProxy::register_object(const Glib::RefPtr<Gio::DBus::Connection> & conn, NoteManager & manager,
+void RemoteControlProxy::register_object(const Glib::RefPtr<Gio::DBus::Connection> & conn, NoteManagerBase & manager,
                                          const slot_name_acquire_finish & on_finish)
 {
   load_introspection_xml();
-  s_remote_control = new RemoteControl(conn, manager, GNOTE_SERVER_PATH, GNOTE_INTERFACE_NAME, s_gnote_interface);
-  s_search_provider = new org::gnome::Gnote::SearchProvider(conn, GNOTE_SEARCH_PROVIDER_PATH,
-                                                            s_search_provider_interface, manager);
+  m_remote_control = new RemoteControl(conn, m_gnote, manager, GNOTE_SERVER_PATH, GNOTE_INTERFACE_NAME, m_gnote_interface);
+  m_search_provider = new org::gnome::Gnote::SearchProvider(conn, GNOTE_SEARCH_PROVIDER_PATH,
+                                                            m_search_provider_interface, m_gnote, manager);
   on_finish(true, true);
 }
 
 
 void RemoteControlProxy::on_name_lost(const Glib::RefPtr<Gio::DBus::Connection> &, const Glib::ustring &)
 {
-  s_on_name_acquire_finish(s_bus_acquired, false);
+  m_on_name_acquire_finish(m_bus_acquired, false);
 }
 
 
 void RemoteControlProxy::load_introspection_xml()
 {
-  load_interface_from_file(DATADIR"/gnote/gnote-introspect.xml", GNOTE_INTERFACE_NAME, s_gnote_interface);
+  load_interface_from_file(DATADIR"/gnote/gnote-introspect.xml", GNOTE_INTERFACE_NAME, m_gnote_interface);
   load_interface_from_file(DATADIR"/gnote/shell-search-provider-dbus-interfaces.xml",
-                           GNOTE_SEARCH_PROVIDER_INTERFACE_NAME, s_search_provider_interface);
+                           GNOTE_SEARCH_PROVIDER_INTERFACE_NAME, m_search_provider_interface);
 }
 
 }
