@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -30,6 +30,7 @@
 #include "debug.hpp"
 #include "iactionmanager.hpp"
 #include "iconmanager.hpp"
+#include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
@@ -45,15 +46,16 @@
 namespace gnote {
 
 
-Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::get_note_icon()
+Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::get_note_icon(IconManager & manager)
 {
-  return IconManager::obj().get_icon(IconManager::NOTE, 22);
+  return manager.get_icon(IconManager::NOTE, 22);
 }
 
 
-SearchNotesWidget::SearchNotesWidget(NoteManager & m)
+SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
   : m_accel_group(Gtk::AccelGroup::create())
   , m_no_matches_box(NULL)
+  , m_gnote(g)
   , m_manager(m)
   , m_clickX(0), m_clickY(0)
   , m_matches_column(NULL)
@@ -96,17 +98,18 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
   // Watch when notes are added to notebooks so the search
   // results will be updated immediately instead of waiting
   // until the note's queue_save () kicks in.
-  notebooks::NotebookManager::obj().signal_note_added_to_notebook()
+  notebooks::NotebookManager & notebook_manager = g.notebook_manager();
+  notebook_manager.signal_note_added_to_notebook()
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_added_to_notebook));
-  notebooks::NotebookManager::obj().signal_note_removed_from_notebook()
+  notebook_manager.signal_note_removed_from_notebook()
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_removed_from_notebook));
-  notebooks::NotebookManager::obj().signal_note_pin_status_changed
+  notebook_manager.signal_note_pin_status_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_pin_status_changed));
 
-  Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+  Glib::RefPtr<Gio::Settings> settings = g.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
   settings->signal_changed().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
   parse_sorting_setting(settings->get_string(Preferences::SEARCH_SORTING));
-  settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
+  settings = g.preferences().get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
   settings->signal_changed().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
 }
 
@@ -124,7 +127,7 @@ Glib::ustring SearchNotesWidget::get_name() const
 {
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
   if(!selected_notebook
-     || dynamic_pointer_cast<notebooks::AllNotesNotebook>(selected_notebook)) {
+     || std::dynamic_pointer_cast<notebooks::AllNotesNotebook>(selected_notebook)) {
     return "";
   }
   return selected_notebook->get_name();
@@ -178,7 +181,7 @@ void SearchNotesWidget::perform_search()
 
   // Search using the currently selected notebook
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
-  if(dynamic_pointer_cast<notebooks::SpecialNotebook>(selected_notebook)) {
+  if(std::dynamic_pointer_cast<notebooks::SpecialNotebook>(selected_notebook)) {
     selected_notebook = notebooks::Notebook::Ptr();
   }
 
@@ -212,10 +215,7 @@ void SearchNotesWidget::restore_matches_window()
 
 Gtk::Widget *SearchNotesWidget::make_notebooks_pane()
 {
-  m_notebooksTree = Gtk::manage(
-    new notebooks::NotebooksTreeView(m_manager,
-                                     notebooks::NotebookManager::obj()
-                                       .get_notebooks_with_special_items()));
+  m_notebooksTree = Gtk::manage(new notebooks::NotebooksTreeView(m_manager, m_gnote.notebook_manager().get_notebooks_with_special_items()));
 
   m_notebooksTree->get_selection()->set_mode(Gtk::SELECTION_SINGLE);
   m_notebooksTree->set_headers_visible(true);
@@ -271,7 +271,7 @@ void SearchNotesWidget::save_position()
     return;
   }
 
-  Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+  Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
     .get_schema_settings(Preferences::SCHEMA_GNOTE);
   settings->set_int(Preferences::SEARCH_WINDOW_SPLITTER_POS, get_position());
 
@@ -296,12 +296,12 @@ void SearchNotesWidget::notebook_pixbuf_cell_data_func(Gtk::CellRenderer * rende
   }
 
   Gtk::CellRendererPixbuf *crp = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
-  notebooks::SpecialNotebook::Ptr special_nb = dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook);
+  notebooks::SpecialNotebook::Ptr special_nb = std::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook);
   if(special_nb) {
-    crp->property_pixbuf() = special_nb->get_icon();
+    crp->property_pixbuf() = special_nb->get_icon(m_gnote.icon_manager());
   }
   else {
-    crp->property_pixbuf() = IconManager::obj().get_icon(IconManager::NOTEBOOK, 22);
+    crp->property_pixbuf() = m_gnote.icon_manager().get_icon(IconManager::NOTEBOOK, 22);
   }
 }
 
@@ -319,7 +319,7 @@ void SearchNotesWidget::notebook_text_cell_data_func(Gtk::CellRenderer * rendere
 
   crt->property_text() = notebook->get_name();
 
-  if(dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
+  if(std::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
     // Bold the "Special" Notebooks
     crt->property_markup() = Glib::ustring::compose("<span weight=\"bold\">%1</span>",
                                  notebook->get_name());
@@ -332,26 +332,25 @@ void SearchNotesWidget::notebook_text_cell_data_func(Gtk::CellRenderer * rendere
 void SearchNotesWidget::on_notebook_row_edited(const Glib::ustring& /*tree_path*/,
                                                const Glib::ustring& new_text)
 {
-  if(notebooks::NotebookManager::obj().notebook_exists(new_text) || new_text == "") {
+  notebooks::NotebookManager & notebook_manager = m_gnote.notebook_manager();
+  if(notebook_manager.notebook_exists(new_text) || new_text == "") {
     return;
   }
   notebooks::Notebook::Ptr old_notebook = this->get_selected_notebook();
-  if(dynamic_pointer_cast<notebooks::SpecialNotebook>(old_notebook)) {
+  if(std::dynamic_pointer_cast<notebooks::SpecialNotebook>(old_notebook)) {
     return;
   }
-  notebooks::Notebook::Ptr new_notebook = notebooks::NotebookManager::obj()
-    .get_or_create_notebook(new_text);
+  notebooks::Notebook::Ptr new_notebook = notebook_manager.get_or_create_notebook(new_text);
   DBG_OUT("Renaming notebook '{%s}' to '{%s}'", old_notebook->get_name().c_str(),
           new_text.c_str());
-  std::list<NoteBase*> notes;
-  old_notebook->get_tag()->get_notes(notes);
-  FOREACH(NoteBase *note, notes) {
-    notebooks::NotebookManager::obj().move_note_to_notebook(
-      static_pointer_cast<Note>(note->shared_from_this()), new_notebook);
+  auto notes = old_notebook->get_tag()->get_notes();
+  for(NoteBase *note : notes) {
+    notebook_manager.move_note_to_notebook(
+      std::static_pointer_cast<Note>(note->shared_from_this()), new_notebook);
   }
-  notebooks::NotebookManager::obj().delete_notebook(old_notebook);
+  notebook_manager.delete_notebook(old_notebook);
   Gtk::TreeIter iter;
-  if(notebooks::NotebookManager::obj().get_notebook_iter(new_notebook, iter)) {
+  if(notebook_manager.get_notebook_iter(new_notebook, iter)) {
     m_notebooksTree->get_selection()->select(iter);
     m_notebooksTree->set_cursor(m_notebooksTree->get_model()->get_path(iter));
   }
@@ -387,7 +386,7 @@ void SearchNotesWidget::on_notebook_selection_changed()
       m_selected_tags.insert(notebook->get_tag());
     }
     bool allow_edit = false;
-    if(dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
+    if(std::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
       m_delete_notebook_action->set_sensitive(false);
       m_rename_notebook_action->set_sensitive(false);
     }
@@ -479,7 +478,7 @@ void SearchNotesWidget::select_all_notes_notebook()
   for(Gtk::TreeIter iter = model->children().begin(); iter; ++iter) {
     notebooks::Notebook::Ptr notebook;
     iter->get_value(0, notebook);
-    if(dynamic_pointer_cast<notebooks::AllNotesNotebook>(notebook) != NULL) {
+    if(std::dynamic_pointer_cast<notebooks::AllNotesNotebook>(notebook) != NULL) {
       m_notebooksTree->get_selection()->select(iter);
       break;
     }
@@ -513,12 +512,12 @@ void SearchNotesWidget::update_results()
 
   int cnt = 0;
 
-  FOREACH(const NoteBase::Ptr & note_iter, m_manager.get_notes()) {
-    Note::Ptr note(static_pointer_cast<Note>(note_iter));
-    Glib::ustring nice_date = utils::get_pretty_print_date(note->change_date(), true);
+  for(const NoteBase::Ptr & note_iter : m_manager.get_notes()) {
+    Note::Ptr note(std::static_pointer_cast<Note>(note_iter));
+    Glib::ustring nice_date = utils::get_pretty_print_date(note->change_date(), true, m_gnote.preferences());
 
     Gtk::TreeIter iter = m_store->append();
-    iter->set_value(0, get_note_icon());  /* icon */
+    iter->set_value(0, get_note_icon(m_gnote.icon_manager()));  /* icon */
     iter->set_value(1, note->get_title()); /* title */
     iter->set_value(2, nice_date);  /* change date */
     iter->set_value(3, note);      /* note */
@@ -619,7 +618,7 @@ int SearchNotesWidget::compare_dates(const Gtk::TreeIter & a, const Gtk::TreeIte
     return -1;
   }
   else {
-    return sharp::DateTime::compare(note_a->change_date(), note_b->change_date());
+    return note_a->change_date().compare(note_b->change_date());
   }
 }
 
@@ -779,11 +778,9 @@ bool SearchNotesWidget::filter_by_tag(const Note::Ptr & note)
   }
 
   //   // FIXME: Ugh!  NOT an O(1) operation.  Is there a better way?
-  std::list<Tag::Ptr> tags;
-  note->get_tags(tags);
-  for(std::list<Tag::Ptr>::const_iterator iter = tags.begin();
-      iter != tags.end(); ++iter) {
-    if(m_selected_tags.find(*iter) != m_selected_tags.end()) {
+  std::vector<Tag::Ptr> tags = note->get_tags();
+  for(auto & tag : tags) {
+    if(m_selected_tags.find(tag) != m_selected_tags.end()) {
       return true;
     }
   }
@@ -1155,20 +1152,20 @@ int SearchNotesWidget::compare_search_hits(const Gtk::TreeIter & a, const Gtk::T
 void SearchNotesWidget::on_note_deleted(const NoteBase::Ptr & note)
 {
   restore_matches_window();
-  delete_note(static_pointer_cast<Note>(note));
+  delete_note(std::static_pointer_cast<Note>(note));
 }
 
 void SearchNotesWidget::on_note_added(const NoteBase::Ptr & note)
 {
   restore_matches_window();
-  add_note(static_pointer_cast<Note>(note));
+  add_note(std::static_pointer_cast<Note>(note));
 }
 
 void SearchNotesWidget::on_note_renamed(const NoteBase::Ptr & note,
                                         const Glib::ustring &)
 {
   restore_matches_window();
-  rename_note(static_pointer_cast<Note>(note));
+  rename_note(std::static_pointer_cast<Note>(note));
 }
 
 void SearchNotesWidget::on_note_saved(const NoteBase::Ptr&)
@@ -1192,10 +1189,9 @@ void SearchNotesWidget::delete_note(const Note::Ptr & note)
 
 void SearchNotesWidget::add_note(const Note::Ptr & note)
 {
-  Glib::ustring nice_date =
-    utils::get_pretty_print_date(note->change_date(), true);
+  Glib::ustring nice_date = utils::get_pretty_print_date(note->change_date(), true, m_gnote.preferences());
   Gtk::TreeIter iter = m_store->append();
-  iter->set_value(m_column_types.icon, get_note_icon());
+  iter->set_value(m_column_types.icon, get_note_icon(m_gnote.icon_manager()));
   iter->set_value(m_column_types.title, note->get_title());
   iter->set_value(m_column_types.change_date, nice_date);
   iter->set_value(m_column_types.note, note);
@@ -1285,7 +1281,7 @@ Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
 {
   if(!m_note_list_context_menu) {
     m_note_list_context_menu = new Gtk::Menu;
-    bool open_notes_in_new_window = Preferences::obj().get_schema_settings(
+    bool open_notes_in_new_window = m_gnote.preferences().get_schema_settings(
       Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
 
     Gtk::MenuItem *item;
@@ -1319,9 +1315,9 @@ void SearchNotesWidget::new_note()
 {
   Note::Ptr note;
   notebooks::Notebook::Ptr notebook = get_selected_notebook();
-  if(!notebook || dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
+  if(!notebook || std::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
     // Just create a standard note (not in a notebook)
-    note = static_pointer_cast<Note>(m_manager.create());
+    note = std::static_pointer_cast<Note>(m_manager.create());
   }
   else {
     // Look for the template note and create a new note
@@ -1372,7 +1368,7 @@ void SearchNotesWidget::on_open_notebook_template_note()
 
 void SearchNotesWidget::on_new_notebook()
 {
-  notebooks::NotebookManager::prompt_create_new_notebook(get_owning_window());
+  notebooks::NotebookManager::prompt_create_new_notebook(m_gnote, get_owning_window());
 }
 
 void SearchNotesWidget::on_delete_notebook()
@@ -1382,7 +1378,7 @@ void SearchNotesWidget::on_delete_notebook()
     return;
   }
 
-  notebooks::NotebookManager::prompt_delete_notebook(get_owning_window(), notebook);
+  notebooks::NotebookManager::prompt_delete_notebook(m_gnote, get_owning_window(), notebook);
 }
 
 void SearchNotesWidget::foreground()
@@ -1395,10 +1391,12 @@ void SearchNotesWidget::foreground()
 
   win->add_accel_group(m_accel_group);
   win->set_focus(*m_tree);
-  auto & manager(IActionManager::obj());
+  auto & manager(m_gnote.action_manager());
   register_callbacks();
   m_callback_changed_cid = manager.signal_main_window_search_actions_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::callbacks_changed));
+  manager.signal_main_window_search_actions_changed
+    .connect([this]{ signal_popover_widgets_changed(); });
 }
 
 void SearchNotesWidget::background()
@@ -1415,7 +1413,7 @@ void SearchNotesWidget::background()
 
 void SearchNotesWidget::hint_size(int & width, int & height)
 {
-  Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+  Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
     .get_schema_settings(Preferences::SCHEMA_GNOTE);
   width = settings->get_int(Preferences::SEARCH_WINDOW_WIDTH);
   height = settings->get_int(Preferences::SEARCH_WINDOW_HEIGHT);
@@ -1423,7 +1421,7 @@ void SearchNotesWidget::hint_size(int & width, int & height)
 
 void SearchNotesWidget::size_internals()
 {
-  Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+  Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
     .get_schema_settings(Preferences::SCHEMA_GNOTE);
   int pos = settings->get_int(Preferences::SEARCH_WINDOW_SPLITTER_POS);
   if(pos) {
@@ -1431,15 +1429,15 @@ void SearchNotesWidget::size_internals()
   }
 }
 
-std::vector<Gtk::Widget*> SearchNotesWidget::get_popover_widgets()
+std::vector<PopoverWidget> SearchNotesWidget::get_popover_widgets()
 {
-  std::map<int, Gtk::Widget*> popover_widgets;
-  IActionManager::obj().signal_build_main_window_search_popover(popover_widgets);
-  std::vector<Gtk::Widget*> widgets;
-  for(auto widget : popover_widgets) {
-    widgets.push_back(widget.second);
+  std::vector<PopoverWidget> popover_widgets;
+  popover_widgets.reserve(20);
+  m_gnote.action_manager().signal_build_main_window_search_popover(popover_widgets);
+  for(unsigned i = 0; i < popover_widgets.size(); ++i) {
+    popover_widgets[i].secondary_order = i;
   }
-  return widgets;
+  return popover_widgets;
 }
 
 std::vector<MainWindowAction::Ptr> SearchNotesWidget::get_widget_actions()
@@ -1487,7 +1485,7 @@ void SearchNotesWidget::on_sorting_changed()
     else {
       value += "desc";
     }
-    Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
+    m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
       Preferences::SEARCH_SORTING, value);
   }
 }
@@ -1555,7 +1553,7 @@ void SearchNotesWidget::register_callbacks()
   if(!win) {
     return;
   }
-  auto & manager(IActionManager::obj());
+  auto & manager(m_gnote.action_manager());
   auto cbacks = manager.get_main_window_search_callbacks();
   for(auto & cback : cbacks) {
     auto action = win->find_action(cback.first);
