@@ -23,6 +23,7 @@
 
 #include <glibmm/i18n.h>
 #include <glibmm/miscutils.h>
+#include <glibmm/thread.h>
 
 #include "debug.hpp"
 #include "filesystemsyncserver.hpp"
@@ -91,17 +92,53 @@ void FileSystemSyncServer::upload_notes(const std::vector<Note::Ptr> & notes)
     sharp::directory_create(m_new_revision_path);
   }
   DBG_OUT("UploadNotes: notes.Count = %d", int(notes.size()));
+  m_updated_notes.reserve(notes.size());
+  Glib::Mutex notes_lock;
+  Glib::Cond all_uploaded;
+  auto cancel_op = Gio::Cancellable::create();
+  unsigned failures = 0;
+  unsigned total = notes.size();
   for(auto & iter : notes) {
-    try {
-      auto server_note = m_new_revision_path->get_child(sharp::file_filename(iter->file_path()));
-      auto local_note = Gio::File::create_for_path(iter->file_path());
-      local_note->copy(server_note);
-      m_updated_notes.push_back(sharp::file_basename(iter->file_path()));
-    }
-    catch(...) {
-      DBG_OUT("Sync: Error uploading note \"%s\"", iter->get_title().c_str());
+    auto file_path = iter->file_path();
+    auto server_note = m_new_revision_path->get_child(sharp::file_filename(file_path));
+    auto local_note = Gio::File::create_for_path(file_path);
+    local_note->copy_async(server_note, [this, &notes_lock, &all_uploaded, &total, &failures, local_note, file_path = std::move(file_path)]
+                                        (Glib::RefPtr<Gio::AsyncResult> & result) {
+      try {
+        if(local_note->copy_finish(result)) {
+          auto path = sharp::file_basename(file_path);
+          notes_lock.lock();
+          m_updated_notes.emplace_back(std::move(path));
+          if(--total == 0) {
+            all_uploaded.signal();
+          }
+          notes_lock.unlock();
+          return;
+        }
+      }
+      catch (Glib::Exception & e) {
+        ERR_OUT(_("Failed to upload note: %s"), e.what().c_str());
+      }
+
+      notes_lock.lock();
+      ++failures;
+      --total;
+      all_uploaded.signal();
+      notes_lock.unlock();
+    }, cancel_op);
+  }
+
+  notes_lock.lock();
+  while(total > 0) {
+    all_uploaded.wait(notes_lock);
+    if(failures > 0) {
+      cancel_op->cancel();
     }
   }
+  notes_lock.unlock();
+  if(failures > 0) {
+    throw GnoteSyncException(Glib::ustring::compose(ngettext("Failed to upload %1 note", "Failed to upload %1 notes", failures), failures));
+  }
 }
 
 
@@ -138,7 +175,10 @@ bool FileSystemSyncServer::updates_available_since(int revision)
 
 std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since(int revision)
 {
+  Glib::Mutex note_updates_lock;
+  Glib::Cond note_updates_done;
   std::map<Glib::ustring, NoteUpdate> noteUpdates;
+  unsigned failures = 0;
 
   Glib::ustring tempPath = Glib::build_filename(m_cache_path, "sync_temp");
   if(!sharp::directory_exists(tempPath)) {
@@ -162,26 +202,66 @@ std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since
     Glib::ustring xpath = Glib::ustring::compose("//note[@rev > %1]", revision);
     sharp::XmlNodeSet noteNodes = sharp::xml_node_xpath_find(root_node, xpath.c_str());
     DBG_OUT("get_note_updates_since xpath returned %d nodes", int(noteNodes.size()));
-    for(sharp::XmlNodeSet::iterator iter = noteNodes.begin(); iter != noteNodes.end(); ++iter) {
-      Glib::ustring note_id = sharp::xml_node_content(sharp::xml_node_xpath_find_single_node(*iter, "@id"));
-      int rev = str_to_int(sharp::xml_node_content(sharp::xml_node_xpath_find_single_node(*iter, "@rev")));
-      if(noteUpdates.find(note_id) == noteUpdates.end()) {
-        // Copy the file from the server to the temp directory
-        auto revDir = get_revision_dir_path(rev);
-        auto serverNotePath = revDir->get_child(note_id + ".note");
-        Glib::ustring noteTempPath = Glib::build_filename(tempPath, note_id + ".note");
-        serverNotePath->copy(Gio::File::create_for_path(noteTempPath));
+    if(noteNodes.size() > 0) {
+      auto cancel_op = Gio::Cancellable::create();
+      for(auto & node : noteNodes) {
+        Glib::ustring note_id = sharp::xml_node_content(sharp::xml_node_xpath_find_single_node(node, "@id"));
+        int rev = str_to_int(sharp::xml_node_content(sharp::xml_node_xpath_find_single_node(node, "@rev")));
+        if(noteUpdates.find(note_id) == noteUpdates.end()) {
+          // Copy the file from the server to the temp directory
+          auto revDir = get_revision_dir_path(rev);
+          auto serverNotePath = revDir->get_child(note_id + ".note");
+          Glib::ustring noteTempPath = Glib::build_filename(tempPath, note_id + ".note");
+          auto dest = Gio::File::create_for_path(noteTempPath);
+          serverNotePath->copy_async(dest,
+            [serverNotePath, &note_updates_lock, &note_updates_done, &noteUpdates, &failures, noteTempPath = std::move(noteTempPath), note_id = std::move(note_id), rev, total = noteNodes.size()]
+            (Glib::RefPtr<Gio::AsyncResult> & result) {
+              try {
+                if(serverNotePath->copy_finish(result)) {
+                  // Get the title, contents, etc.
+                  Glib::ustring noteTitle;
+                  Glib::ustring noteXml = sharp::file_read_all_text(noteTempPath);
+                  NoteUpdate update(noteXml, noteTitle, note_id, rev);
+                  note_updates_lock.lock();
+                  noteUpdates.insert(std::make_pair(note_id, update));
+                  if(noteUpdates.size() + failures >= total) {
+                    note_updates_done.signal();
+                  }
+                  note_updates_lock.unlock();
+                  return; // all done, error handling below
+                }
+              }
+              catch(Glib::Exception & e) {
+                ERR_OUT(_("Exception when finishing note copy: %s"), e.what().c_str());
+              }
+              catch(...) {
+                ERR_OUT(_("Exception when finishing note copy"));
+              }
 
-        // Get the title, contents, etc.
-        Glib::ustring noteTitle;
-        Glib::ustring noteXml = sharp::file_read_all_text(noteTempPath);
-        NoteUpdate update(noteXml, noteTitle, note_id, rev);
-        noteUpdates.insert(std::make_pair(note_id, update));
+              note_updates_lock.lock();
+              ++failures;
+              note_updates_done.signal();
+              note_updates_lock.unlock();
+            }, cancel_op);
+        }
       }
+
+      note_updates_lock.lock();
+      while(noteUpdates.size() + failures < noteNodes.size()) {
+        if(failures > 0 && !cancel_op->is_cancelled()) {
+          cancel_op->cancel();
+        }
+        note_updates_done.wait(note_updates_lock);
+      }
+      note_updates_lock.unlock();
     }
+
     xmlFreeDoc(xml_doc);
   }
 
+  if(failures > 0) {
+    throw GnoteSyncException(Glib::ustring::compose(ngettext("Failed to download %1 note update", "Failed to download %1 note updates", failures), failures));
+  }
   DBG_OUT("get_note_updates_since (%d) returning: %d", revision, int(noteUpdates.size()));
   return noteUpdates;
 }
