@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 
 #include "debug.hpp"
+#include "ignote.hpp"
 #include "isyncmanager.hpp"
 #include "silentui.hpp"
 
@@ -26,14 +27,14 @@
 namespace gnote {
 namespace sync {
 
-  SyncUI::Ptr SilentUI::create(NoteManagerBase & nm)
+  SyncUI::Ptr SilentUI::create(IGnote & g, NoteManagerBase & nm)
   {
-    return SyncUI::Ptr(new SilentUI(nm));
+    return std::make_shared<SilentUI>(g, nm);
   }
 
 
-  SilentUI::SilentUI(NoteManagerBase & manager)
-    : SyncUI(manager)
+  SilentUI::SilentUI(IGnote & g, NoteManagerBase & manager)
+    : SyncUI(g, manager)
     , m_ui_disabled(false)
   {
     signal_connecting_connect(sigc::mem_fun(*this, &SilentUI::on_connecting));
@@ -75,7 +76,7 @@ namespace sync {
 
   void SilentUI::note_conflict_detected(const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
-                                        const std::list<Glib::ustring> &)
+                                        const std::vector<Glib::ustring> &)
   {
     DBG_OUT("note conflict detected, overwriting without a care");
     // TODO: At least respect conflict prefs
@@ -83,7 +84,7 @@ namespace sync {
     if(localConflictNote->id() != remoteNote.m_uuid) {
       m_manager.delete_note(localConflictNote);
     }
-    ISyncManager::obj().resolve_conflict(OVERWRITE_EXISTING);
+    m_gnote.sync_manager().resolve_conflict(OVERWRITE_EXISTING);
   }
 
 
@@ -95,7 +96,7 @@ namespace sync {
   void SilentUI::on_connecting()
   {
     m_manager.read_only(true);
-    FOREACH(const NoteBase::Ptr & iter, m_manager.get_notes()) {
+    for(const NoteBase::Ptr & iter : m_manager.get_notes()) {
       iter->enabled(false);
     }
   }
@@ -104,7 +105,7 @@ namespace sync {
   void SilentUI::on_idle()
   {
     m_manager.read_only(false);
-    FOREACH(const NoteBase::Ptr & iter, m_manager.get_notes()) {
+    for(const NoteBase::Ptr & iter : m_manager.get_notes()) {
       iter->enabled(true);
     }
     m_ui_disabled = false;
