@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #define _SYNCHRONIZATION_SILENTUI_HPP_
 
 
-#include "base/macros.hpp"
 #include "notemanager.hpp"
 #include "syncui.hpp"
 
@@ -35,14 +34,14 @@ namespace sync {
     : public SyncUI
   {
   public:
-    static SyncUI::Ptr create(NoteManagerBase &);
+    static SyncUI::Ptr create(IGnote &, NoteManagerBase &);
+    SilentUI(IGnote &, NoteManagerBase &);
   private:
-    explicit SilentUI(NoteManagerBase &);
     virtual void sync_state_changed(SyncState state) override;
     virtual void note_synchronized(const Glib::ustring & noteTitle, NoteSyncType type) override;
     virtual void note_conflict_detected(const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
-                                        const std::list<Glib::ustring> & noteUpdateTitles) override;
+                                        const std::vector<Glib::ustring> & noteUpdateTitles) override;
     virtual void present_ui() override;
     void on_connecting();
     void on_idle();
