@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2016,2017 Aurimas Cernius
+ * Copyright (C) 2012-2014,2016,2017,2019-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ class SyncTitleConflictDialog
   : public Gtk::Dialog
 {
 public:
-  SyncTitleConflictDialog(const Note::Ptr & existingNote, const std::list<Glib::ustring> & noteUpdateTitles)
+  SyncTitleConflictDialog(const Note::Ptr & existingNote, const std::vector<Glib::ustring> & noteUpdateTitles)
     : Gtk::Dialog(_("Note Conflict"), true)
     , m_existing_note(existingNote)
     , m_note_update_titles(noteUpdateTitles)
@@ -198,7 +198,7 @@ private:
     }
 
   Note::Ptr m_existing_note;
-  std::list<Glib::ustring> m_note_update_titles;
+  std::vector<Glib::ustring> m_note_update_titles;
 
   Gtk::Button *continueButton;
 
@@ -218,14 +218,14 @@ private:
 
 
 
-SyncDialog::Ptr SyncDialog::create(NoteManagerBase & m)
+SyncDialog::Ptr SyncDialog::create(IGnote & g, NoteManagerBase & m)
 {
-  return SyncDialog::Ptr(new SyncDialog(m));
+  return std::make_shared<SyncDialog>(g, m);
 }
 
 
-SyncDialog::SyncDialog(NoteManagerBase & manager)
-  : SyncUI(manager)
+SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
+  : SyncUI(g, manager)
 {
   m_progress_bar_timeout_id = 0;
 
@@ -245,7 +245,7 @@ SyncDialog::SyncDialog(NoteManagerBase & manager)
   hbox->show();
   outerVBox->attach(*hbox, 0, outerVBoxRow++, 1, 1);
 
-  m_image = manage(new Gtk::Image(IconManager::obj().get_icon(IconManager::GNOTE, 48)));
+  m_image = manage(new Gtk::Image(g.icon_manager().get_icon(IconManager::GNOTE, 48)));
   m_image->set_alignment(0, 0);
   m_image->show();
   hbox->attach(*m_image, 0, 0, 1, 1);
@@ -367,7 +367,7 @@ void SyncDialog::on_realize()
 {
   Gtk::Dialog::on_realize();
 
-  SyncState state = ISyncManager::obj().state();
+  SyncState state = m_gnote.sync_manager().state();
   if(state == IDLE) {
     // Kick off a timer to keep the progress bar going
     //m_progress_barTimeoutId = GLib.Timeout.Add (500, OnPulseProgressBar);
@@ -376,7 +376,7 @@ void SyncDialog::on_realize()
     timeout->attach();
 
     // Kick off a new synchronization
-    ISyncManager::obj().perform_synchronization(this->shared_from_this());
+    m_gnote.sync_manager().perform_synchronization(this->shared_from_this());
   }
   else {
     // Adjust the GUI accordingly
@@ -387,7 +387,7 @@ void SyncDialog::on_realize()
 
 bool SyncDialog::on_pulse_progress_bar()
 {
-  if(ISyncManager::obj().state() == IDLE) {
+  if(m_gnote.sync_manager().state() == IDLE) {
     return false;
   }
 
@@ -423,7 +423,7 @@ void SyncDialog::on_row_activated(const Gtk::TreeModel::Path & path, Gtk::TreeVi
 
   NoteBase::Ptr note = m_manager.find(noteTitle);
   if(note != 0) {
-    present_note(static_pointer_cast<Note>(note));
+    present_note(std::static_pointer_cast<Note>(note));
   }
 }
 
@@ -594,106 +594,93 @@ void SyncDialog::note_synchronized(const Glib::ustring & noteTitle, NoteSyncType
 
 void SyncDialog::note_conflict_detected(const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
-                                        const std::list<Glib::ustring> & noteUpdateTitles)
+                                        const std::vector<Glib::ustring> & noteUpdateTitles)
 {
-  int dlgBehaviorPref = Preferences::obj()
+  int dlgBehaviorPref = m_gnote.preferences()
     .get_schema_settings(Preferences::SCHEMA_SYNC)->get_int(Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR);
-  std::exception *mainThreadException = NULL;
 
   // This event handler will be called by the synchronization thread
   // so we have to use the delegate here to manipulate the GUI.
   // To be consistent, any exceptions in the delgate will be caught
   // and then rethrown in the synchronization thread.
   utils::main_context_call(
-    [this, localConflictNote, remoteNote, noteUpdateTitles, dlgBehaviorPref, &mainThreadException]() {
+    [this, localConflictNote, remoteNote, noteUpdateTitles, dlgBehaviorPref]() {
       note_conflict_detected_(localConflictNote, remoteNote, noteUpdateTitles,
                               static_cast<SyncTitleConflictResolution>(dlgBehaviorPref),
-                              OVERWRITE_EXISTING, &mainThreadException
+                              OVERWRITE_EXISTING
       );
     });
-
-  if(mainThreadException) {
-    std::exception e(*mainThreadException);
-    delete mainThreadException;
-    throw e;
-  }
 }
 
 
 void SyncDialog::note_conflict_detected_(
   const Note::Ptr & localConflictNote,
   NoteUpdate remoteNote,
-  const std::list<Glib::ustring> & noteUpdateTitles,
+  const std::vector<Glib::ustring> & noteUpdateTitles,
   SyncTitleConflictResolution savedBehavior,
-  SyncTitleConflictResolution resolution,
-  std::exception **mainThreadException)
+  SyncTitleConflictResolution resolution)
 {
-  try {
-    SyncTitleConflictDialog conflictDlg(localConflictNote, noteUpdateTitles);
-    Gtk::ResponseType reponse = Gtk::RESPONSE_OK;
+  SyncTitleConflictDialog conflictDlg(localConflictNote, noteUpdateTitles);
+  Gtk::ResponseType reponse = Gtk::RESPONSE_OK;
 
-    bool noteSyncBitsMatch = ISyncManager::obj().synchronized_note_xml_matches(
-      localConflictNote->get_complete_note_xml(), remoteNote.m_xml_content);
+  bool noteSyncBitsMatch = m_gnote.sync_manager().synchronized_note_xml_matches(
+    localConflictNote->get_complete_note_xml(), remoteNote.m_xml_content);
 
-    // If the synchronized note content is in conflict
-    // and there is no saved conflict handling behavior, show the dialog
-    if(!noteSyncBitsMatch && savedBehavior == 0) {
-      reponse = static_cast<Gtk::ResponseType>(conflictDlg.run());
+  // If the synchronized note content is in conflict
+  // and there is no saved conflict handling behavior, show the dialog
+  if(!noteSyncBitsMatch && savedBehavior == 0) {
+    reponse = static_cast<Gtk::ResponseType>(conflictDlg.run());
+  }
+
+
+  if(reponse == Gtk::RESPONSE_CANCEL) {
+    resolution = CANCEL;
+  }
+  else {
+    if(noteSyncBitsMatch) {
+      resolution = OVERWRITE_EXISTING;
     }
-
-
-    if(reponse == Gtk::RESPONSE_CANCEL) {
-      resolution = CANCEL;
+    else if(savedBehavior == 0) {
+      resolution = conflictDlg.resolution();
     }
     else {
-      if(noteSyncBitsMatch) {
-        resolution = OVERWRITE_EXISTING;
-      }
-      else if(savedBehavior == 0) {
-        resolution = conflictDlg.resolution();
-      }
-      else {
-        resolution = savedBehavior;
-      }
-
-      switch(resolution) {
-      case OVERWRITE_EXISTING:
-        if(conflictDlg.always_perform_this_action()) {
-          savedBehavior = resolution;
-        }
-        // No need to delete if sync will overwrite
-        if(localConflictNote->id() != remoteNote.m_uuid) {
-          m_manager.delete_note(localConflictNote);
-        }
-        break;
-      case RENAME_EXISTING_AND_UPDATE:
-        if(conflictDlg.always_perform_this_action()) {
-          savedBehavior = resolution;
-        }
-        rename_note(localConflictNote, conflictDlg.renamed_title(), true);
-        break;
-      case RENAME_EXISTING_NO_UPDATE:
-        if(conflictDlg.always_perform_this_action()) {
-          savedBehavior = resolution;
-        }
-        rename_note(localConflictNote, conflictDlg.renamed_title(), false);
-        break;
-      case CANCEL:
-        break;
-      }
+      resolution = savedBehavior;
     }
 
-    Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
-      Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR, static_cast<int>(savedBehavior)); // TODO: Clean up
-
-    conflictDlg.hide();
-
-    // Let the SyncManager continue
-    ISyncManager::obj().resolve_conflict(/*localConflictNote, */resolution);
-  }
-  catch(std::exception & e) {
-    *mainThreadException = new std::exception(e);
+    switch(resolution) {
+    case OVERWRITE_EXISTING:
+      if(conflictDlg.always_perform_this_action()) {
+        savedBehavior = resolution;
+      }
+      // No need to delete if sync will overwrite
+      if(localConflictNote->id() != remoteNote.m_uuid) {
+        m_manager.delete_note(localConflictNote);
+      }
+      break;
+    case RENAME_EXISTING_AND_UPDATE:
+      if(conflictDlg.always_perform_this_action()) {
+        savedBehavior = resolution;
+      }
+      rename_note(localConflictNote, conflictDlg.renamed_title(), true);
+      break;
+    case RENAME_EXISTING_NO_UPDATE:
+      if(conflictDlg.always_perform_this_action()) {
+        savedBehavior = resolution;
+      }
+      rename_note(localConflictNote, conflictDlg.renamed_title(), false);
+      break;
+    case CANCEL:
+      break;
+    }
   }
+
+  m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_SYNC)->set_int(
+    Preferences::SYNC_CONFIGURED_CONFLICT_BEHAVIOR, static_cast<int>(savedBehavior)); // TODO: Clean up
+
+  conflictDlg.hide();
+
+  // Let the SyncManager continue
+  m_gnote.sync_manager().resolve_conflict(/*localConflictNote, */resolution);
 }
 
 
@@ -712,9 +699,9 @@ void SyncDialog::rename_note(const Note::Ptr & note, const Glib::ustring & newTi
   note->save(); // Write to file
   bool noteOpen = note->is_opened();
   Glib::ustring newContent = //note.XmlContent;
-    NoteArchiver::obj().get_renamed_note_xml(note->xml_content(), oldTitle, newTitle);
+    m_manager.note_archiver().get_renamed_note_xml(note->xml_content(), oldTitle, newTitle);
   Glib::ustring newCompleteContent = //note.GetCompleteNoteXml ();
-    NoteArchiver::obj().get_renamed_note_xml(note->get_complete_note_xml(), oldTitle, newTitle);
+    m_manager.note_archiver().get_renamed_note_xml(note->get_complete_note_xml(), oldTitle, newTitle);
   //Logger.Debug ("RenameNote: newContent: " + newContent);
   //Logger.Debug ("RenameNote: newCompleteContent: " + newCompleteContent);
 
@@ -723,7 +710,7 @@ void SyncDialog::rename_note(const Note::Ptr & note, const Glib::ustring & newTi
 
   // Create note with old XmlContent just in case GetCompleteNoteXml failed
   DBG_OUT("RenameNote: about to create %s", newTitle.c_str());
-  Note::Ptr renamedNote = static_pointer_cast<Note>(m_manager.create(newTitle, newContent));
+  Note::Ptr renamedNote = std::static_pointer_cast<Note>(m_manager.create(newTitle, newContent));
   if(newCompleteContent != "") {// TODO: Anything to do if it is null?
     try {
       renamedNote->load_foreign_note_xml(newCompleteContent, OTHER_DATA_CHANGED);
@@ -737,7 +724,7 @@ void SyncDialog::rename_note(const Note::Ptr & note, const Glib::ustring & newTi
 
 void SyncDialog::present_note(const Note::Ptr & note)
 {
-  MainWindow::present_in(IGnote::obj().get_window_for_note(), note);
+  MainWindow::present_in(m_gnote.get_window_for_note(), note);
 }
 
 }
