@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 #include <gtkmm/treestore.h>
 #include <gtkmm/treeviewcolumn.h>
 
-#include "base/macros.hpp"
 #include "syncui.hpp"
 
 
@@ -40,15 +39,16 @@ namespace sync {
     , public SyncUI
   {
   public:
-    typedef shared_ptr<SyncDialog> Ptr;
+    typedef std::shared_ptr<SyncDialog> Ptr;
 
-    static Ptr create(NoteManagerBase &);
+    static Ptr create(IGnote &, NoteManagerBase &);
 
+    SyncDialog(IGnote &, NoteManagerBase &);
     virtual void sync_state_changed(SyncState state) override;
     virtual void note_synchronized(const Glib::ustring & noteTitle, NoteSyncType type) override;
     virtual void note_conflict_detected(const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
-                                        const std::list<Glib::ustring> & noteUpdateTitles) override;
+                                        const std::vector<Glib::ustring> & noteUpdateTitles) override;
     virtual void present_ui() override;
     void header_text(const Glib::ustring &);
     void message_text(const Glib::ustring &);
@@ -61,12 +61,10 @@ namespace sync {
     static void on_expander_activated(GtkExpander*, gpointer);
     void note_conflict_detected_(const Note::Ptr & localConflictNote,
                                  NoteUpdate remoteNote,
-                                 const std::list<Glib::ustring> & noteUpdateTitles,
+                                 const std::vector<Glib::ustring> & noteUpdateTitles,
                                  SyncTitleConflictResolution savedBehavior,
-                                 SyncTitleConflictResolution resolution,
-                                 std::exception **mainThreadException);
+                                 SyncTitleConflictResolution resolution);
 
-    explicit SyncDialog(NoteManagerBase &);
     bool on_pulse_progress_bar();
     void on_row_activated(const Gtk::TreeModel::Path & path, Gtk::TreeViewColumn *column);
     void treeview_col1_data_func(Gtk::CellRenderer *renderer, const Gtk::TreeIter & iter);
