@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,22 +22,22 @@
 #define _SYNCHRONIZATION_SYNCUI_HPP_
 
 
-#include <list>
-
 #include <glibmm/ustring.h>
 
-#include "base/macros.hpp"
 #include "syncutils.hpp"
 
 
 namespace gnote {
+
+  class IGnote;
+
 namespace sync {
 
   class SyncUI
-    : public enable_shared_from_this<SyncUI>
+    : public std::enable_shared_from_this<SyncUI>
   {
   public:
-    typedef shared_ptr<SyncUI> Ptr;
+    typedef std::shared_ptr<SyncUI> Ptr;
     typedef sigc::slot<void> SlotConnecting;
     typedef sigc::slot<void> SlotIdle;
 
@@ -46,7 +46,7 @@ namespace sync {
     virtual void note_synchronized(const Glib::ustring & noteTitle, NoteSyncType type) = 0;
     virtual void note_conflict_detected(const Note::Ptr & localConflictNote,
                                         NoteUpdate remoteNote,
-                                        const std::list<Glib::ustring> & noteUpdateTitles) = 0;
+                                        const std::vector<Glib::ustring> & noteUpdateTitles) = 0;
     virtual void present_ui() = 0;
 
     sigc::connection signal_connecting_connect(const SlotConnecting & slot);
@@ -54,8 +54,9 @@ namespace sync {
     sigc::connection signal_idle_connect(const SlotIdle & slot);
     void signal_idle_emit();
   protected:
-    explicit SyncUI(NoteManagerBase & manager);
+    SyncUI(IGnote & g, NoteManagerBase & manager);
 
+    IGnote & m_gnote;
     NoteManagerBase & m_manager;
   private:
     void signal_connecting_emit_()
