@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2017 Aurimas Cernius
+ * Copyright (C) 2013,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@
 #include <gtkmm/liststore.h>
 #include <gtkmm/treemodelsort.h>
 
-#include "base/macros.hpp"
 #include "itagmanager.hpp"
 #include "tag.hpp"
 
@@ -53,7 +52,7 @@ public:
     {
       return m_sorted_tags;
     }
-  virtual void all_tags(std::list<Tag::Ptr> &) const override;
+  virtual std::vector<Tag::Ptr> all_tags() const override;
 private:
   class ColumnRecord
     : public Gtk::TreeModelColumnRecord
