@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014,2017-2018 Aurimas Cernius
+ * Copyright (C) 2014,2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,9 @@
  */
 
 
-#include "base/macros.hpp"
+#ifndef _TESTTAGMANAGER_HPP_
+#define _TESTTAGMANAGER_HPP_
+
 #include "itagmanager.hpp"
 
 namespace test {
@@ -27,19 +29,17 @@ class TagManager
   : public gnote::ITagManager
 {
 public:
-  static void ensure_exists();
-
   virtual gnote::Tag::Ptr get_tag(const Glib::ustring & tag_name) const override;
   virtual gnote::Tag::Ptr get_or_create_tag(const Glib::ustring &) override;
   virtual gnote::Tag::Ptr get_system_tag(const Glib::ustring & tag_name) const override;
   virtual gnote::Tag::Ptr get_or_create_system_tag(const Glib::ustring & name) override;
   virtual void remove_tag(const gnote::Tag::Ptr & tag) override;
-  virtual void all_tags(std::list<gnote::Tag::Ptr> &) const override;
+  virtual std::vector<gnote::Tag::Ptr> all_tags() const override;
 private:
-  static TagManager* s_manager;
-
   std::map<Glib::ustring, gnote::Tag::Ptr> m_tags;
 };
 
 }
 
+#endif
+
