@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017-2019 Aurimas Cernius
+ * Copyright (C) 2017-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,10 +36,26 @@
 using namespace gnote;
 
 
+void remove_dir(const Glib::ustring dir)
+{
+  auto subitems = sharp::directory_get_directories(dir);
+  for(auto subdir : subitems) {
+    remove_dir(subdir);
+  }
+  subitems = sharp::directory_get_files(dir);
+  for(auto file : subitems) {
+    g_remove(file.c_str());
+  }
+  g_rmdir(dir.c_str());
+}
+
+
 SUITE(SyncManagerTests)
 {
   struct Fixture
   {
+    Glib::ustring tempdir1;
+    Glib::ustring tempdir2;
     Glib::ustring notesdir1;
     Glib::ustring notesdir2;
     Glib::ustring syncdir;
@@ -55,14 +71,14 @@ SUITE(SyncManagerTests)
 
     Fixture()
     {
-      Glib::ustring notes_dir1 = make_temp_dir();
-      Glib::ustring notes_dir2 = make_temp_dir();
-      notesdir1 = notes_dir1 + "/notes";
-      notesdir2 = notes_dir2 + "/notes";
-      syncdir = notes_dir1 + "/sync";
+      tempdir1 = make_temp_dir();
+      tempdir2 = make_temp_dir();
+      notesdir1 = tempdir1 + "/notes";
+      notesdir2 = tempdir2 + "/notes";
+      syncdir = tempdir1 + "/sync";
       REQUIRE CHECK(g_mkdir(syncdir.c_str(), S_IRWXU) == 0);
-      manifest1 = notes_dir1 + "/manifest.xml";
-      manifest2 = notes_dir2 + "/manifest.xml";
+      manifest1 = tempdir1 + "/manifest.xml";
+      manifest2 = tempdir2 + "/manifest.xml";
 
       manager1 = new test::NoteManager(notesdir1, gnote1);
       gnote1.notebook_manager(&manager1->notebook_manager());
@@ -83,6 +99,8 @@ SUITE(SyncManagerTests)
     {
       delete manager1;
       delete manager2;
+      remove_dir(tempdir1);
+      remove_dir(tempdir2);
     }
 
     Glib::ustring make_temp_dir()
@@ -156,7 +174,7 @@ SUITE(SyncManagerTests)
     FIRST_SYNC(gnote2, sync_manager2, manager2, manifest2, sync_client2, sync_ui2)
 
     get_notes_in_dir(notesdir2);
-    REQUIRE CHECK_EQUAL(4, files.size()); // 3 downloaded notes + template
+    REQUIRE CHECK_EQUAL(3, files.size());
     CHECK(find_note_in_files("note1"));
     CHECK(find_note_in_files("note2"));
     CHECK(find_note_in_files("note3"));
@@ -172,7 +190,7 @@ SUITE(SyncManagerTests)
     Glib::ustring syncednotesdir = syncdir + "/0/1";
     REQUIRE CHECK(sharp::directory_exists(syncednotesdir));
     get_notes_in_dir(syncednotesdir);
-    REQUIRE CHECK_EQUAL(2, files.size());  // note + template note
+    REQUIRE CHECK_EQUAL(1, files.size());
     CHECK(find_note_in_files("note4"));
   }
 
@@ -189,12 +207,12 @@ SUITE(SyncManagerTests)
     Glib::ustring syncednotesdir = syncdir + "/0";
     REQUIRE CHECK(sharp::directory_exists(syncednotesdir));
     files = sharp::directory_get_directories(syncednotesdir);
-    CHECK_EQUAL(3, files.size());
+    CHECK_EQUAL(2, files.size());  // first time client2 only downloads
 
     // sync to first client
     sync_manager1->perform_synchronization(sync_ui1);
     get_notes_in_dir(notesdir1);
-    CHECK(4 <= files.size()); // 3 original + 1 from other client + templates
+    CHECK_EQUAL(4, files.size()); // 3 original + 1 from other client
     CHECK(find_note_in_files("note4"));
   }
 
@@ -216,7 +234,7 @@ SUITE(SyncManagerTests)
     FIRST_SYNC(gnote2, sync_manager2, manager2, manifest2, sync_client2, sync_ui2)
 
     get_notes_in_dir(notesdir2);
-    REQUIRE CHECK_EQUAL(4, files.size()); // 3 downloaded notes + template
+    REQUIRE CHECK_EQUAL(3, files.size());
     CHECK(!find_note_in_files("note2"));
     CHECK(find_note_in_files("note4"));
   }
@@ -234,7 +252,7 @@ SUITE(SyncManagerTests)
     // download updates
     sync_manager2->perform_synchronization(sync_ui2);
     get_notes_in_dir(notesdir2);
-    REQUIRE CHECK(3 <= files.size()); // 3 downloaded notes + templates
+    REQUIRE CHECK_EQUAL(3, files.size());
     CHECK(find_note_in_files("note1"));
     CHECK(find_note_in_files("note3"));
     CHECK(find_note_in_files("note4"));
@@ -252,7 +270,7 @@ SUITE(SyncManagerTests)
 
     FIRST_SYNC(gnote2, sync_manager2, manager2, manifest2, sync_client2, sync_ui2)
     get_notes_in_dir(notesdir2);
-    REQUIRE CHECK_EQUAL(3, files.size()); // 2 downloaded notes + template
+    REQUIRE CHECK_EQUAL(2, files.size());
     CHECK(find_note_in_files("note1"));
     CHECK(find_note_in_files("note3"));
     CHECK(!find_note_in_files("note2"));
@@ -276,7 +294,7 @@ SUITE(SyncManagerTests)
     // sync client1 again
     sync_manager1->perform_synchronization(sync_ui1);
     get_notes_in_dir(notesdir2);
-    REQUIRE CHECK(3 <= files.size()); // 3 downloaded notes + templates
+    REQUIRE CHECK_EQUAL(3, files.size());
     CHECK(find_note_in_files("note1"));
     CHECK(find_note_in_files("note3"));
     CHECK(!find_note_in_files("note2"));
@@ -298,7 +316,7 @@ SUITE(SyncManagerTests)
     sync_client1.reparse();
     sync_manager1->perform_synchronization(sync_ui1);
     get_notes_in_dir(notesdir1);
-    REQUIRE CHECK_EQUAL(3, files.size()); // 2 downloaded notes + template
+    REQUIRE CHECK_EQUAL(2, files.size());
     CHECK(find_note_in_files("note1"));
     CHECK(find_note_in_files("note3"));
     CHECK(!find_note_in_files("note2"));
