@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -34,8 +34,6 @@
 #include <gtkmm/checkmenuitem.h>
 #include <gtkmm/icontheme.h>
 #include <gtkmm/image.h>
-#include <gtkmm/label.h>
-#include <gtkmm/modelbutton.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/textbuffer.h>
 
@@ -43,7 +41,6 @@
 #include "sharp/xmlwriter.hpp"
 #include "sharp/string.hpp"
 #include "sharp/uri.hpp"
-#include "sharp/datetime.hpp"
 #include "preferences.hpp"
 #include "note.hpp"
 #include "utils.hpp"
@@ -99,43 +96,7 @@ namespace gnote {
         delete slot;
         return FALSE;
       }
-
-      void main_context_call_func(const sigc::slot<void> & slot,
-                                  Glib::Threads::Cond * cond,
-                                  Glib::Threads::Mutex * mutex)
-      {
-        mutex->lock();
-        slot();
-        cond->signal();
-        mutex->unlock();
-      }
-
-
-      class PopoverSubmenuBox
-        : public Gtk::Box
-        , public PopoverSubmenu
-      {
-      public:
-        PopoverSubmenuBox(const Glib::ustring & submenu)
-          : Gtk::Box(Gtk::ORIENTATION_VERTICAL)
-          , PopoverSubmenu(submenu)
-        {
-          utils::set_common_popover_widget_props(*this);
-        }
-      };
-
-      void set_common_popover_widget_props(Gtk::ModelButton & button)
-      {
-        button.set_use_underline(true);
-        button.property_margin_top() = 3;
-        button.property_margin_bottom() = 3;
-        auto lbl = dynamic_cast<Gtk::Label*>(button.get_child());
-        if(lbl) {
-          lbl->set_xalign(0.0f);
-        }
-        utils::set_common_popover_widget_props(button);
-      }
-    }
+   }
 
 
     void popup_menu(Gtk::Menu &menu, const GdkEventButton * ev)
@@ -210,43 +171,46 @@ namespace gnote {
       dialog.run ();
     }
 
-    Glib::ustring get_pretty_print_date(const sharp::DateTime & date, bool show_time)
+    Glib::ustring get_pretty_print_date(const Glib::DateTime & date, bool show_time, Preferences & preferences)
     {
       bool use_12h = false;
       if(show_time) {
-        use_12h = Preferences::obj().get_schema_settings(
-          Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE)->get_string(
+        use_12h = preferences.get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE)->get_string(
             Preferences::DESKTOP_GNOME_CLOCK_FORMAT) == "12h";
       }
       return get_pretty_print_date(date, show_time, use_12h);
     }
 
-    Glib::ustring get_pretty_print_date(const sharp::DateTime & date, bool show_time, bool use_12h)
+    Glib::ustring get_pretty_print_date(const Glib::DateTime & date, bool show_time, bool use_12h)
     {
+      if(!date) {
+        return _("No Date");
+      }
+
       Glib::ustring pretty_str;
-      sharp::DateTime now = sharp::DateTime::now();
+      auto now = Glib::DateTime::create_now_local();
       Glib::ustring short_time = use_12h
         /* TRANSLATORS: time in 12h format. */
-        ? date.to_string("%l:%M %P")
+        ? sharp::date_time_to_string(date, "%l:%M %P")
         /* TRANSLATORS: time in 24h format. */
-        : date.to_string("%H:%M");
+        : sharp::date_time_to_string(date, "%H:%M");
 
-      if (date.year() == now.year()) {
-        if (date.day_of_year() == now.day_of_year()) {
+      if(date.get_year() == now.get_year()) {
+        if(date.get_day_of_year() == now.get_day_of_year()) {
           pretty_str = show_time ?
             /* TRANSLATORS: argument %1 is time. */
             Glib::ustring::compose(_("Today, %1"), short_time) :
             _("Today");
         }
-        else if ((date.day_of_year() < now.day_of_year())
-                 && (date.day_of_year() == now.day_of_year() - 1)) {
+        else if((date.get_day_of_year() < now.get_day_of_year())
+                 && (date.get_day_of_year() == now.get_day_of_year() - 1)) {
           pretty_str = show_time ?
             /* TRANSLATORS: argument %1 is time. */
             Glib::ustring::compose(_("Yesterday, %1"), short_time) :
             _("Yesterday");
         }
-        else if (date.day_of_year() > now.day_of_year()
-                 && date.day_of_year() == now.day_of_year() + 1) {
+        else if(date.get_day_of_year() > now.get_day_of_year()
+                 && date.get_day_of_year() == now.get_day_of_year() + 1) {
           pretty_str = show_time ?
             /* TRANSLATORS: argument %1 is time. */
             Glib::ustring::compose(_("Tomorrow, %1"), short_time) :
@@ -254,19 +218,16 @@ namespace gnote {
         }
         else {
           /* TRANSLATORS: date in current year. */
-          pretty_str = date.to_string(_("%b %d")); // "MMMM d"
+          pretty_str = sharp::date_time_to_string(date, _("%b %d")); // "MMMM d"
           if(show_time) {
             /* TRANSLATORS: argument %1 is date, %2 is time. */
             pretty_str = Glib::ustring::compose(_("%1, %2"), pretty_str, short_time);
           }
         }
       } 
-      else if (!date.is_valid()) {
-        pretty_str = _("No Date");
-      }
       else {
         /* TRANSLATORS: date in other than current year. */
-        pretty_str = date.to_string(_("%b %d %Y")); // "MMMM d yyyy"
+        pretty_str = sharp::date_time_to_string(date, _("%b %d %Y")); // "MMMM d yyyy"
         if(show_time) {
           /* TRANSLATORS: argument %1 is date, %2 is time. */
           pretty_str = Glib::ustring::compose(_("%1, %2"), pretty_str, short_time);
@@ -287,68 +248,28 @@ namespace gnote {
     {
       Glib::Threads::Mutex mutex;
       Glib::Threads::Cond cond;
+      bool executed = false;
+      std::exception_ptr ex;
 
       mutex.lock();
-      main_context_invoke([slot, &cond, &mutex]() {
-        main_context_call_func(slot, &cond, &mutex);
+      main_context_invoke([slot, &cond, &mutex, &executed, &ex]() {
+        try {
+          mutex.lock();
+          slot();
+        }
+        catch(...) {
+          ex = std::current_exception();
+        }
+        executed = true;
+        cond.signal();
+        mutex.unlock();
       });
-      cond.wait(mutex);
+      while(!executed) {
+        cond.wait(mutex);
+      }
       mutex.unlock();
-    }
-
-
-    Gtk::Widget * create_popover_button(const Glib::ustring & action, const Glib::ustring & label)
-    {
-      Gtk::ModelButton *item = new Gtk::ModelButton;
-      gtk_actionable_set_action_name(GTK_ACTIONABLE(item->gobj()), action.c_str());
-      item->set_label(label);
-      set_common_popover_widget_props(*item);
-      return item;
-    }
-
-
-    Gtk::Widget * create_popover_submenu_button(const Glib::ustring & submenu, const Glib::ustring & label)
-    {
-      Gtk::ModelButton *button = new Gtk::ModelButton;
-      button->property_menu_name() = submenu;
-      button->set_label(label);
-      set_common_popover_widget_props(*button);
-      return button;
-    }
-
-
-    Gtk::Box * create_popover_submenu(const Glib::ustring & name)
-    {
-      return new PopoverSubmenuBox(name);
-    }
-
-
-    void set_common_popover_widget_props(Gtk::Widget & widget)
-    {
-      widget.property_hexpand() = true;
-    }
-
-    void set_common_popover_widget_props(Gtk::Box & widget)
-    {
-      widget.property_margin_top() = 9;
-      widget.property_margin_bottom() = 9;
-      widget.property_margin_left() = 12;
-      widget.property_margin_right() = 12;
-      set_common_popover_widget_props(static_cast<Gtk::Widget&>(widget));
-    }
-
-
-    void add_item_to_ordered_map(std::map<int, Gtk::Widget*> & dest, int order, Gtk::Widget *item)
-    {
-      for(; dest.find(order) != dest.end(); ++order);
-      dest[order] = item;
-    }
-
-
-    void merge_ordered_maps(std::map<int, Gtk::Widget*> & dest, const std::map<int, Gtk::Widget*> & adds)
-    {
-      for(std::map<int, Gtk::Widget*>::const_iterator iter = adds.begin(); iter != adds.end(); ++iter) {
-        add_item_to_ordered_map(dest, iter->first, iter->second);
+      if(ex) {
+        std::rethrow_exception(ex);
       }
     }
 
@@ -372,7 +293,7 @@ namespace gnote {
     {
       m_fake_menu.set_sensitive(enable);
       std::vector<Gtk::Widget*> items = m_fake_menu.get_children();
-      FOREACH(Gtk::Widget *item, items) {
+      for(Gtk::Widget *item : items) {
         item->set_sensitive(enable);
       }
     }
@@ -614,8 +535,9 @@ namespace gnote {
     }
 
 
-    void UriList::get_local_paths(std::list<Glib::ustring> & paths) const
+    std::vector<Glib::ustring> UriList::get_local_paths() const
     {
+      std::vector<Glib::ustring> paths;
       for(const_iterator iter = begin(); iter != end(); ++iter) {
 
         const sharp::Uri & uri(*iter);
@@ -624,6 +546,8 @@ namespace gnote {
           paths.push_back(uri.local_path());
         }
       }
+
+      return paths;
     }
 
 
@@ -783,7 +707,7 @@ namespace gnote {
     }
 
 
-    bool InterruptableTimeout::callback(InterruptableTimeout* self)
+    int InterruptableTimeout::callback(InterruptableTimeout* self)
     {
       if(self)
         return self->timeout_expired();
